RetroForward

Trait RetroForward 

pub trait RetroForward:
    Debug
    + Send
    + 'static {
    // Required method
    fn forward(&self, states: &mut BackwardStates, out_node: NodeId);
}
Definition of the forward function of a node, called during retropropagation only. This is different from the normal forward function because it reads and writes from the BackwardStates map instead of having a clear function signature.

Required Methods

fn forward(&self, states: &mut BackwardStates, out_node: NodeId)

Applies the forward pass for retropropagation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors