Enum OperationIr
pub enum OperationIr {
Show 14 variants
BaseFloat(BaseOperationIr),
BaseInt(BaseOperationIr),
BaseBool(BaseOperationIr),
NumericFloat(DType, NumericOperationIr),
NumericInt(DType, NumericOperationIr),
Bool(BoolOperationIr),
Int(IntOperationIr),
Float(DType, FloatOperationIr),
Module(ModuleOperationIr),
Init(InitOperationIr),
Custom(CustomOpIr),
Drop(TensorIr),
Distributed(DistributedOperationIr),
Activation(ActivationOperationIr),
}Expand description
Describe all tensor operations possible.
Variants
BaseFloat(BaseOperationIr)
Basic operation on a float tensor.
BaseInt(BaseOperationIr)
Basic operation on an int tensor.
BaseBool(BaseOperationIr)
Basic operation on a bool tensor.
NumericFloat(DType, NumericOperationIr)
Numeric operation on a float tensor.
NumericInt(DType, NumericOperationIr)
Numeric operation on an int tensor.
Bool(BoolOperationIr)
Operation specific to a bool tensor.
Int(IntOperationIr)
Operation specific to an int tensor.
Float(DType, FloatOperationIr)
Operation specific to a float tensor.
Module(ModuleOperationIr)
Module operation.
Init(InitOperationIr)
Initialize operation.
Custom(CustomOpIr)
A custom operation.
Drop(TensorIr)
A tensor is dropped.
Distributed(DistributedOperationIr)
Operation specific to a distributed tensor.
Activation(ActivationOperationIr)
Activation function operation (relu, gelu, sigmoid, softmax, …).
Implementations
impl OperationIr
impl OperationIr
pub fn inputs(&self) -> impl Iterator<Item = &TensorIr>
pub fn inputs(&self) -> impl Iterator<Item = &TensorIr>
Get all input tensors involved with the current operation.
pub fn outputs(&self) -> impl Iterator<Item = &TensorIr>
pub fn outputs(&self) -> impl Iterator<Item = &TensorIr>
Get all output tensors involved with the current operation.
pub fn mark_read_only(&mut self, nodes: &[TensorId]) -> Vec<TensorIr>
pub fn mark_read_only(&mut self, nodes: &[TensorId]) -> Vec<TensorIr>
Set the given nodes that are read write to read only in the current operation.
Returns the tensor that were updated with their original representation.
pub fn visit_mut(&mut self, v: &mut impl IrVisitorMut)
pub fn visit_mut(&mut self, v: &mut impl IrVisitorMut)