Struct TensorIr
pub struct TensorIr {
pub id: TensorId,
pub shape: Shape,
pub status: TensorStatus,
pub dtype: DType,
}Expand description
A tensor definition represents a snapshot of a tensor when it was used.
Example
A tensor that is used multiple times has its status updated for each operation.
- Status::NotInit
- Status::ReadOnly
- Status::ReadOnly
- Status::ReadWrite
Fields
id: TensorIdThe tensor id.
shape: ShapeThe shape of the tensor.
status: TensorStatusThe status of the tensor when it was used.
dtype: DTypeThe type of the tensor.
Implementations