Struct TensorSpec
pub struct TensorSpec {
pub shape: Shape,
pub dtype: DType,
}Expand description
Shape and element type of a tensor, without access to its data or handle.
Metadata callbacks receive specs for inputs and return specs for outputs.
Fields
shape: ShapeTensor dimensions.
dtype: DTypeTensor element type.
Implementations
impl TensorSpec
impl TensorSpec
pub fn new(shape: Shape, dtype: DType) -> TensorSpec
pub fn new(shape: Shape, dtype: DType) -> TensorSpec
Describe an output tensor.