Struct OrderedExecution
pub struct OrderedExecution<R>where
R: FusionRuntime,{ /* private fields */ }Expand description
Manage the execution of potentially multiple optimizations and operations out of order.
Implementations
impl<R> OrderedExecution<R>where
R: FusionRuntime,
impl<R> OrderedExecution<R>where
R: FusionRuntime,
pub fn operation_within_optimization(&self, index: usize) -> FallbackOp<R>
pub fn operation_within_optimization(&self, index: usize) -> FallbackOp<R>
Returns the operation that can be executed without impacting the state of the execution.
This is useful to implement fallback for optimizations.