FusionTensor

Struct FusionTensor 

pub struct FusionTensor<R>
where R: FusionRuntime,
{ pub id: TensorId, pub shape: Shape, pub client: GlobalFusionClient<R>, pub dtype: DType, pub stream: StreamId, /* private fields */ }
Tensor primitive for the fusion backend for all kind.

Fields

id: TensorId

Tensor id.

shape: Shape

The shape of the tensor.

client: GlobalFusionClient<R>

The fusion client.

dtype: DType

The datatype of the tensor.

stream: StreamId

The current stream id this tensor is on.

Implementations



impl<R> FusionTensor<R>
where R: FusionRuntime,

pub fn to_ir_out(&self) -> TensorIr

Intermediate representation to be used when using an uninitialized tensor as output.

pub fn into_ir(self) -> TensorIr

Intermediate representation to be used when using an initialized tensor used as input.