NumOperations

Trait NumOperations 

pub trait NumOperations: Debug {
    // Required methods
    fn len(&self) -> usize;
    fn name(&self) -> &'static str;

    // Provided methods
    fn is_empty(&self) -> bool { ... }
    fn max_relative_shape_id(&self) -> Option<usize> { ... }
}
The number of operations contained in the data structure.

Required Methods

fn len(&self) -> usize

The number of registered operations.

fn name(&self) -> &'static str

The name of the optimization.

Provided Methods

fn is_empty(&self) -> bool

If the current optimization is empty.

fn max_relative_shape_id(&self) -> Option<usize>

The highest relative shape id this optimization names, if it names any. None means the optimization names no relative shape, so it fits any stream.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors