NumericOperationIr

Enum NumericOperationIr 

pub enum NumericOperationIr {
Show 56 variants Add(BinaryOpIr), AddScalar(ScalarOpIr), Sub(BinaryOpIr), SubScalar(ScalarOpIr), Div(BinaryOpIr), DivScalar(ScalarOpIr), Rem(BinaryOpIr), RemScalar(ScalarOpIr), Mul(BinaryOpIr), MulScalar(ScalarOpIr), Abs(UnaryOpIr), Full(FullOpIr), MeanDim(ReduceDimOpIr), Mean(ReduceOpIr), Sum(ReduceOpIr), SumDim(ReduceDimOpIr), SumDims(ReduceDimsOpIr), Prod(ReduceOpIr), ProdDim(ReduceDimOpIr), Greater(BinaryOpIr), GreaterElem(ScalarOpIr), GreaterEqual(BinaryOpIr), GreaterEqualElem(ScalarOpIr), Lower(BinaryOpIr), LowerElem(ScalarOpIr), LowerEqual(BinaryOpIr), LowerEqualElem(ScalarOpIr), ArgMax(ReduceDimOpIr), ArgTopK(ReduceDimOpIr), TopK(ReduceDimOpIr), TopKWithIndices(TopKWithIndicesOpIr), ArgMin(ReduceDimOpIr), Max(ReduceOpIr), MaxDimWithIndices(ReduceDimWithIndicesOpIr), MinDimWithIndices(ReduceDimWithIndicesOpIr), Min(ReduceOpIr), MaxDim(ReduceDimOpIr), MinDim(ReduceDimOpIr), MaxAbs(ReduceOpIr), MaxAbsDim(ReduceDimOpIr), Clamp(ClampOpIr), IntRandom(RandomOpIr), Powi(BinaryOpIr), PowiScalar(ScalarOpIr), CumSum(DimOpIr), CumProd(DimOpIr), CumMin(DimOpIr), CumMax(DimOpIr), Neg(UnaryOpIr), Sign(UnaryOpIr), ClampMin(ScalarOpIr), ClampMax(ScalarOpIr), Sort(SortOpIr), SortWithIndices(SortWithIndicesOpIr), ArgSort(SortOpIr), Pad(PadOpIr),
}
Numeric operations on int and float tensors.

Variants



Add(BinaryOpIr)

Operation corresponding to:

Float => add. Int => add.



AddScalar(ScalarOpIr)

Operation corresponding to:

Float => add scalar. Int => add scalar.



Sub(BinaryOpIr)

Operation corresponding to:

Float => sub. Int => sub.



SubScalar(ScalarOpIr)

Operation corresponding to:

Float => sub scalar. Int => sub scalar.



Div(BinaryOpIr)

Operation corresponding to:

Float => div. Int => div.



DivScalar(ScalarOpIr)

Operation corresponding to:

Float => div scalar. Int => div scalar.



Rem(BinaryOpIr)

Operation corresponding to:

Float => rem. Int => rem.



RemScalar(ScalarOpIr)

Operation corresponding to:

Float => rem scalar. Int => rem scalar.



Mul(BinaryOpIr)

Operation corresponding to:

Float => mul. Int => mul.



MulScalar(ScalarOpIr)

Operation corresponding to:

Float => mul scalar. Int => mul scalar.



Abs(UnaryOpIr)

Operation corresponding to:

Float => abs. Int => abs.



Full(FullOpIr)

Operation corresponding to:

Float => full. Int => full.



MeanDim(ReduceDimOpIr)

Operation corresponding to:

Float => mean dim. Int => mean dim.



Mean(ReduceOpIr)

Operation corresponding to:

Float => mean. Int => mean.



Sum(ReduceOpIr)

Operation corresponding to:

Float => sum. Int => sum.



SumDim(ReduceDimOpIr)

Operation corresponding to:

Float => sum dim. Int => sum dim.



SumDims(ReduceDimsOpIr)

Operation corresponding to summing several dimensions at once.



Prod(ReduceOpIr)

Operation corresponding to:

Float => prod. Int => prod.



ProdDim(ReduceDimOpIr)

Operation corresponding to:

Float => prod dim. Int => prod dim.



Greater(BinaryOpIr)

Operation corresponding to:

Float => greater. Int => greater.



GreaterElem(ScalarOpIr)

Operation corresponding to:

Float => greater elem. Int => greater elem.



GreaterEqual(BinaryOpIr)

Operation corresponding to:

Float => greater equal. Int => greater elem.



GreaterEqualElem(ScalarOpIr)

Operation corresponding to:

Float => greater equal elem. Int => greater equal elem.



Lower(BinaryOpIr)

Operation corresponding to:

Float => lower. Int => lower.



LowerElem(ScalarOpIr)

Operation corresponding to:

Float => lower elem. Int => lower elem.



LowerEqual(BinaryOpIr)

Operation corresponding to:

Float => lower equal. Int => lower equal.



LowerEqualElem(ScalarOpIr)

Operation corresponding to:

Float => lower equal elem. Int => lower equal elem.



ArgMax(ReduceDimOpIr)

Operation corresponding to:

Float => argmax. Int => argmax.



ArgTopK(ReduceDimOpIr)

Operation corresponding to:

Float => argtopk. Int => argtopk.



TopK(ReduceDimOpIr)

Operation corresponding to:

Float => topk. Int => topk.



TopKWithIndices(TopKWithIndicesOpIr)

Operation corresponding to:

Float => topk with indices. Int => topk with indices.



ArgMin(ReduceDimOpIr)

Operation corresponding to:

Float => argmin. Int => argmin.



Max(ReduceOpIr)

Operation corresponding to:

Float => max. Int => max.



MaxDimWithIndices(ReduceDimWithIndicesOpIr)

Operation corresponding to:

Float => max dim with indices. Int => max dim with indices.



MinDimWithIndices(ReduceDimWithIndicesOpIr)

Operation corresponding to:

Float => min dim with indices. Int => min dim with indices.



Min(ReduceOpIr)

Operation corresponding to:

Float => min. Int => min.



MaxDim(ReduceDimOpIr)

Operation corresponding to:

Float => max dim. Int => max dim.



MinDim(ReduceDimOpIr)

Operation corresponding to:

Float => min dim. Int => min dim.



MaxAbs(ReduceOpIr)

Operation corresponding to:

Float => max_abs. Int => max_abs.



MaxAbsDim(ReduceDimOpIr)

Operation corresponding to:

Float => max_abs dim. Int => max_abs dim.



Clamp(ClampOpIr)

Operation corresponding to:

Float => clamp. Int => clamp.



IntRandom(RandomOpIr)

Operation corresponding to:

Int => random.



Powi(BinaryOpIr)

Operation corresponding to:

Float => powf. Int => powf.



PowiScalar(ScalarOpIr)

Operation corresponding to:

Float => powi_scalar. Int => powi_scalar.



CumSum(DimOpIr)

Operation corresponding to:

Float => cumsum. Int => cumsum.



CumProd(DimOpIr)

Operation corresponding to:

Float => cumprod. Int => cumprod.



CumMin(DimOpIr)

Operation corresponding to:

Float => cummin. Int => cummin.



CumMax(DimOpIr)

Operation corresponding to:

Float => cummax. Int => cummax.



Neg(UnaryOpIr)

Operation corresponding to:

Float => neg. Int => neg.



Sign(UnaryOpIr)

Operation corresponding to:

Float => sign. Int => sign.



ClampMin(ScalarOpIr)

Operation corresponding to:

Float => clamp_min. Int => clamp_min.



ClampMax(ScalarOpIr)

Operation corresponding to:

Float => clamp_max. Int => clamp_max.



Sort(SortOpIr)

Sort along a dim. Output shares the input’s shape and dtype.



SortWithIndices(SortWithIndicesOpIr)

Sort along a dim, also returning the source indices.



ArgSort(SortOpIr)

Sort along a dim and return only the indices (i.e., the argsort).

Shares SortOpIr with Sort; only the output dtype differs.



Pad(PadOpIr)

Operation corresponding to:

Float => pad. Int => pad.