Struct DimOpIr
pub struct DimOpIr {
pub input: TensorIr,
pub out: TensorIr,
pub axis: usize,
}Expand description
IR for operations that operate along a dimension without reducing it.
Unlike ReduceDimOpIr, the output shape is the same as the input shape.
Fields
input: TensorIrout: TensorIraxis: usizeImplementations