Struct GraphId
pub struct GraphId(pub u64);Expand description
Identifier for a cached, reusable group of operations (a graph).
A router backend that supports graph caching (e.g. the remote backend) registers a relative op-graph once under this id, then replays it by id with only the changing bindings.
Tuple Fields
0: u64Trait Implementations
impl Copy for GraphId
impl<'de> Deserialize<'de> for GraphId
impl<'de> Deserialize<'de> for GraphId
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GraphId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GraphId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GraphId
impl Serialize for GraphId
impl Serialize for GraphId
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for GraphId