Struct QuantizationParametersIr
pub struct QuantizationParametersIr {
pub scales: TensorIr,
pub global: Option<TensorIr>,
}Expand description
Quantization parameters intermediate representation.
Fields
scales: TensorIrThe scaling factor, one per block or a single one for a per-tensor level.
global: Option<TensorIr>The per-tensor scale that scales are expressed relative to, for a
two-level scheme.