Struct ReduceDimOpIr
pub struct ReduceDimOpIr {
pub input: TensorIr,
pub out: TensorIr,
pub axis: usize,
pub accumulator_len: usize,
}Fields
input: TensorIrout: TensorIraxis: usizeaccumulator_len: usizeImplementations
impl ReduceDimOpIr
impl ReduceDimOpIr
impl ReduceDimOpIr
impl ReduceDimOpIr
pub fn create_arg(
input: TensorIr,
axis: usize,
accumulator_len: usize,
ind_dtype: DType,
new_id: impl FnOnce() -> TensorId,
) -> ReduceDimOpIr
pub fn create_arg( input: TensorIr, axis: usize, accumulator_len: usize, ind_dtype: DType, new_id: impl FnOnce() -> TensorId, ) -> ReduceDimOpIr
Create a new operation IR from the given inputs and the given output dtype.
impl ReduceDimOpIr
impl ReduceDimOpIr
pub fn create_bool(
input: TensorIr,
axis: usize,
accumulator_len: usize,
bool_dtype: DType,
new_id: impl FnOnce() -> TensorId,
) -> ReduceDimOpIr
pub fn create_bool( input: TensorIr, axis: usize, accumulator_len: usize, bool_dtype: DType, new_id: impl FnOnce() -> TensorId, ) -> ReduceDimOpIr
Create a new operation IR from the given inputs and the given output dtype.