min_abs_norm

Function min_abs_norm 

pub fn min_abs_norm<const D: usize, K>(
    x: Tensor<D, K>,
    dim: impl AsIndex,
) -> Tensor<D, K>
where K: Ordered,
Computes the L:NEG_INFINITY norm of a tensor along a specified dimension.

Arguments

  • x - The input tensor.
  • dim - The dimension to compute the norm over. Negative dimensions are supported and count from the end.

Returns

The L:NEG_INFINITY norm of the input tensor.