Struct ModuleLrScheduler
pub struct ModuleLrScheduler { /* private fields */ }Expand description
A learning rate scheduler that maps specific parameter groups to dedicated sub-schedulers.
This allows heterogeneous learning rate schedules across different layers of a model (e.g., discriminative layer training or fine-tuning).
Implementations
impl ModuleLrScheduler
impl ModuleLrScheduler
pub fn new<S>(scheduler: S) -> ModuleLrSchedulerwhere
S: LrScheduler + 'static,
pub fn new<S>(scheduler: S) -> ModuleLrSchedulerwhere
S: LrScheduler + 'static,
pub fn step(&mut self) -> ModuleLearningRate
pub fn step(&mut self) -> ModuleLearningRate
Perform the scheduler step of every scheduler and returns the effective learning rate policy.
pub fn to_record(&self) -> LrSchedulerRecord
pub fn to_record(&self) -> LrSchedulerRecord
Get the current state of the schedulers as a record.
pub fn load_record(self, record: LrSchedulerRecord) -> ModuleLrScheduler
pub fn load_record(self, record: LrSchedulerRecord) -> ModuleLrScheduler
Load the state of the schedulers from a record.
pub fn with_group(
self,
group: ParamGroup,
scheduler: impl Into<DynLrScheduler>,
) -> ModuleLrScheduler
pub fn with_group( self, group: ParamGroup, scheduler: impl Into<DynLrScheduler>, ) -> ModuleLrScheduler
Add a new parameter group to the scheduler’s policy.