Struct DynLrScheduler
pub struct DynLrScheduler { /* private fields */ }Expand description
A wrapper over a dynamic LrScheduler.
Implementations
impl DynLrScheduler
impl DynLrScheduler
pub fn step(&mut self) -> f64
pub fn step(&mut self) -> f64
Perform the scheduler step, potentially updating its state, and returning the effective learning rate.
pub fn to_record(&self) -> LrSchedulerRecord
pub fn to_record(&self) -> LrSchedulerRecord
Get the current state of the scheduler as a record.
pub fn load_record(self, record: LrSchedulerRecord) -> DynLrScheduler
pub fn load_record(self, record: LrSchedulerRecord) -> DynLrScheduler
Load the state of the scheduler from a record.