Struct Content
pub struct Content {
pub attributes: Vec<Attribute>,
pub single_item: Option<String>,
pub display_settings: DisplaySettings,
pub top_level_type: Option<String>,
}Expand description
Struct to store the attributes of a module for formatting.
Fields
attributes: Vec<Attribute>List of attributes.
single_item: Option<String>Single item content.
display_settings: DisplaySettingsDisplay settings.
top_level_type: Option<String>Top level type name.
Implementations
impl Content
impl Content
pub fn new(display_settings: DisplaySettings) -> Content
pub fn new(display_settings: DisplaySettings) -> Content
pub fn add_debug_attribute<T>(self, name: &str, value: &T) -> Contentwhere
T: Debug,
pub fn add_debug_attribute<T>(self, name: &str, value: &T) -> Contentwhere
T: Debug,
Adds an attribute using its Debug representation.
This is intended for fields that do not implement ModuleDisplay.
Arguments
name- Name of the attribute.value- Value of the attribute.
Returns
Updated Content instance with the new attribute added.
pub fn add_single<T>(self, value: &T) -> Contentwhere
T: ModuleDisplay + ?Sized,
pub fn add_single<T>(self, value: &T) -> Contentwhere
T: ModuleDisplay + ?Sized,
pub fn add_formatted<T>(self, value: &T) -> Contentwhere
T: Display,
pub fn add_formatted<T>(self, value: &T) -> Contentwhere
T: Display,
pub fn optional(self) -> Option<Content>
pub fn optional(self) -> Option<Content>
A convenience method to wrap the Attributes struct in an option because it is often used as an optional field.
Returns
An optional Content.
pub fn set_top_level_type(self, ty: &str) -> Content
pub fn set_top_level_type(self, ty: &str) -> Content