Struct EmptyRecord
pub struct EmptyRecord;Expand description
A record representing the absence of persistent module state.
EmptyRecord is used for modules that do not store any data to be
serialized or restored (e.g., modules marked with #[module(skip)]
or modules without parameters).
This record contains no fields and serializes to None.
Implementations
impl EmptyRecord
impl EmptyRecord
pub fn new() -> EmptyRecord
pub fn new() -> EmptyRecord
Constructs a new EmptyRecord.