ParamGroup

Struct ParamGroup 

pub struct ParamGroup { /* private fields */ }
A way to represent a group of parameter for a Burn module.

Implementations



impl ParamGroup

pub fn matches(&self, id: &ParamId, path: Option<&str>) -> bool

Evaluates whether a given parameter ID and its module path match this group.

pub fn ids_from_module<M>(module: M) -> ParamGroup
where M: Module,

Returns a parameter group with all of the module’s parameters.

pub fn from_path(path: impl Into<String>) -> ParamGroup

Matches parameters by exact text path (e.g., “model.backbone.linear.weight”)

pub fn from_paths(paths: Vec<impl Into<String>>) -> ParamGroup

Matches parameters by exact text paths (e.g., “model.backbone.linear.weight”, etc.)

pub fn from_predicate(path: impl Into<String>) -> ParamGroup

Matches parameters that include the predicate in their paths (e.g., “backbone”)

pub fn from_predicates(paths: Vec<impl Into<String>>) -> ParamGroup

Matches parameters that include all the predicates in their path (AND logic). (e.g., parameter path contains “backbone” and “linear”)

pub fn from_any_predicates(paths: Vec<impl Into<String>>) -> ParamGroup

Matches parameters that include any of the predicates in their path (OR logic). (e.g., parameter path contains “backbone” or “linear”)

pub fn from_regex<S>(pattern: S) -> Result<ParamGroup, ParamGroupError>
where S: AsRef<str>,

Matches parameters by regex pattern (e.g., “^model.layer.\d+$”)

Errors

Returns a ParamGroupError::InvalidPatternError if the string cannot be compiled into a valid regex.

pub fn from_regexes<S>(patterns: Vec<S>) -> Result<ParamGroup, ParamGroupError>
where S: AsRef<str>,

Matches parameters for all the regex patterns (AND logic). (e.g., “^encoder.layer.\d+”, and “bias$” )

Errors

Returns a ParamGroupError::InvalidPatternError if the strings cannot be compiled into a valid regex.

pub fn from_any_regexes<S>( patterns: Vec<S>, ) -> Result<ParamGroup, ParamGroupError>
where S: AsRef<str>,

Matches parameters for any the regex patterns (OR logic). (e.g., “^encoder.layer.\d+$”, or “^decoder.layer.\d+$” )

Errors

Returns a ParamGroupError::InvalidPatternError if the strings cannot be compiled into a valid regex.

pub fn all() -> ParamGroup

Matches any parameter.

pub fn from_ids(ids: Vec<ParamId>) -> ParamGroup

Matches a specific slice of predefined parameter IDs.

pub fn fuse(self, other: &ParamGroup) -> ParamGroup

Fuse two parameter group.

pub fn exclude(self, group: ParamGroup) -> ParamGroup

Exclude the given group from the current group