Struct SwiGluConfig
pub struct SwiGluConfig {
pub d_input: usize,
pub d_output: usize,
pub bias: bool,
pub initializer: Initializer,
pub layout: LinearLayout,
}Expand description
Configuration to create a SwiGlu activation layer using the init function.
Fields
d_input: usizeThe size of the input features.
d_output: usizeThe size of the output features.
bias: boolIf a bias should be applied during the linear transformation. Default behaviour is False for SwiGLU activation implementations.
initializer: InitializerThe type of function used to initialize the linear layer parameters
layout: LinearLayoutThe layout in which the linear parameters are stored.
Implementations
impl SwiGluConfig
impl SwiGluConfig
pub fn new(d_input: usize, d_output: usize) -> SwiGluConfig
pub fn new(d_input: usize, d_output: usize) -> SwiGluConfig
Create a new instance of the config.
Arguments
Required Arguments
d_input
The size of the input features.
d_output
The size of the output features.
Default Arguments
bias
If a bias should be applied during the linear transformation. Default behaviour is False for SwiGLU activation implementations.
- Defaults to
false
initializer
The type of function used to initialize the linear layer parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0), fan_out_only:false}"
layout
The layout in which the linear parameters are stored.
- Defaults to
"LinearLayout::Row"
impl SwiGluConfig
impl SwiGluConfig
pub fn with_bias(self, bias: bool) -> SwiGluConfig
pub fn with_bias(self, bias: bool) -> SwiGluConfig
Sets the value for the field bias.
If a bias should be applied during the linear transformation. Default behaviour is False for SwiGLU activation implementations.
- Defaults to
false
pub fn with_initializer(self, initializer: Initializer) -> SwiGluConfig
pub fn with_initializer(self, initializer: Initializer) -> SwiGluConfig
Sets the value for the field initializer.
The type of function used to initialize the linear layer parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0), fan_out_only:false}"
pub fn with_layout(self, layout: LinearLayout) -> SwiGluConfig
pub fn with_layout(self, layout: LinearLayout) -> SwiGluConfig
Sets the value for the field layout.
The layout in which the linear parameters are stored.
- Defaults to
"LinearLayout::Row"
impl SwiGluConfig
impl SwiGluConfig