Struct CTCLossConfig
pub struct CTCLossConfig {
pub blank: usize,
pub zero_infinity: bool,
}Expand description
Configuration for the CTC Loss module.
Fields
blank: usizeThe index number used to represent the blank label. Default value is 0.
zero_infinity: boolWhether to zero infinite losses and the associated gradients. Default value is false.
Implementations
impl CTCLossConfig
impl CTCLossConfig
pub fn new() -> CTCLossConfig
pub fn new() -> CTCLossConfig
impl CTCLossConfig
impl CTCLossConfig
pub fn with_blank(self, blank: usize) -> CTCLossConfig
pub fn with_blank(self, blank: usize) -> CTCLossConfig
Sets the value for the field blank.
The index number used to represent the blank label. Default value is 0.
- Defaults to
0
pub fn with_zero_infinity(self, zero_infinity: bool) -> CTCLossConfig
pub fn with_zero_infinity(self, zero_infinity: bool) -> CTCLossConfig
Sets the value for the field zero_infinity.
Whether to zero infinite losses and the associated gradients. Default value is false.
- Defaults to
false
impl CTCLossConfig
impl CTCLossConfig