Struct CrossEntropyLossConfig
pub struct CrossEntropyLossConfig {
pub pad_tokens: Option<Vec<usize>>,
pub weights: Option<Vec<f32>>,
pub smoothing: Option<f32>,
pub logits: bool,
}Expand description
Configuration to create a Cross-entropy loss using the init function.
Fields
pad_tokens: Option<Vec<usize>>Create padded cross entropy.
Prevents pad tokens from impacting loss calculation.
weights: Option<Vec<f32>>Create weighted cross-entropy.
The loss of a specific sample will simply be given by: weight * log(p(x)) * 1,
Pre-conditions
- The order of the weight vector should correspond to the label integer assignment.
- Targets assigned negative Int’s will not be allowed.
smoothing: Option<f32>Create cross-entropy with label smoothing.
Hard labels {0, 1} will be changed to y_smoothed = y(1 - a) + a / nr_classes. Alpha = 0 would be the same as default.
logits: boolCreate cross-entropy with probabilities as input instead of logits.
Implementations
impl CrossEntropyLossConfig
impl CrossEntropyLossConfig
pub fn new() -> CrossEntropyLossConfig
pub fn new() -> CrossEntropyLossConfig
Create a new instance of the config.
Arguments
Optional Arguments
pad_tokens
Create padded cross entropy.
Prevents pad tokens from impacting loss calculation.
- Defaults to
None
weights
Create weighted cross-entropy.
The loss of a specific sample will simply be given by: weight * log(p(x)) * 1,
Pre-conditions
- The order of the weight vector should correspond to the label integer assignment.
- Targets assigned negative Int’s will not be allowed.
- Defaults to
None
smoothing
Create cross-entropy with label smoothing.
Hard labels {0, 1} will be changed to y_smoothed = y(1 - a) + a / nr_classes. Alpha = 0 would be the same as default.
- Defaults to
None
Default Arguments
logits
Create cross-entropy with probabilities as input instead of logits.
- Defaults to
true
impl CrossEntropyLossConfig
impl CrossEntropyLossConfig
pub fn with_logits(self, logits: bool) -> CrossEntropyLossConfig
pub fn with_logits(self, logits: bool) -> CrossEntropyLossConfig
Sets the value for the field logits.
Create cross-entropy with probabilities as input instead of logits.
- Defaults to
true
pub fn with_pad_tokens(
self,
pad_tokens: Option<Vec<usize>>,
) -> CrossEntropyLossConfig
pub fn with_pad_tokens( self, pad_tokens: Option<Vec<usize>>, ) -> CrossEntropyLossConfig
Sets the value for the field pad_tokens.
Create padded cross entropy.
Prevents pad tokens from impacting loss calculation.
- Defaults to
None
pub fn with_weights(self, weights: Option<Vec<f32>>) -> CrossEntropyLossConfig
pub fn with_weights(self, weights: Option<Vec<f32>>) -> CrossEntropyLossConfig
Sets the value for the field weights.
Create weighted cross-entropy.
The loss of a specific sample will simply be given by: weight * log(p(x)) * 1,
Pre-conditions
- The order of the weight vector should correspond to the label integer assignment.
- Targets assigned negative Int’s will not be allowed.
- Defaults to
None
pub fn with_smoothing(self, smoothing: Option<f32>) -> CrossEntropyLossConfig
pub fn with_smoothing(self, smoothing: Option<f32>) -> CrossEntropyLossConfig
Sets the value for the field smoothing.
Create cross-entropy with label smoothing.
Hard labels {0, 1} will be changed to y_smoothed = y(1 - a) + a / nr_classes. Alpha = 0 would be the same as default.
- Defaults to
None
impl CrossEntropyLossConfig
impl CrossEntropyLossConfig
pub fn init<B>(
&self,
device: &<B as BackendTypes>::Device,
) -> CrossEntropyLoss<B>where
B: Backend,
pub fn init<B>(
&self,
device: &<B as BackendTypes>::Device,
) -> CrossEntropyLoss<B>where
B: Backend,
Initialize Cross-entropy loss.