Struct KLDivLoss
pub struct KLDivLoss {
pub log_target: bool,
}Expand description
Kullback-Leibler Divergence Loss
KL Divergence shows the difference between two probability distributions by measuring information loss
KLDivLoss =
y_{true} \cdot (\log{y_{true}} - \log{y_{pred}})
```
By default, the loss expects the input in the log-space.
The targets may also be provided in the log-space if `log_target` is true.
See
- [Kullback–Leibler divergence](https://en.wikipedia.org/wiki/Kullback-Leibler_divergence)Fields
log_target: boolSpecifies whether target is the log space. Default: False.
Implementations
impl KLDivLoss
impl KLDivLoss
pub fn forward<const D: usize, B>(
&self,
predictions: Tensor<B, D>,
targets: Tensor<B, D>,
reduction: Reduction,
) -> Tensor<B, 1>where
B: Backend,
pub fn forward<const D: usize, B>(
&self,
predictions: Tensor<B, D>,
targets: Tensor<B, D>,
reduction: Reduction,
) -> Tensor<B, 1>where
B: Backend,
Compute the criterion on the input tensor.
Reduction::Auto behaves as Reduction::BatchMean,Reduction::Mean dose not align with the math definition.
Shapes
- predictions: [batch_size,num_targets]
- targets: [batch_size,num_targets]
- output: [1]