Module basic

Module basic 

Basic RNN.

Structs

BiRnn
The BiRnn module. This implementation is for Bidirectional RNN. Should be created with BiRnnConfig.
BiRnnConfig
Configuration to create a BiRnn module using the init function.
BiRnnRecord
The record type for the module.
BiRnnRecordItem
The record item type for the module.
Rnn
The Rnn module. This implementation is for a unidirectional, stateless, Rnn. Should be created with RnnConfig.
RnnConfig
Configuration to create a Rnn module using the init function.
RnnRecord
The record type for the module.
RnnRecordItem
The record item type for the module.
RnnState
A RnnState is used to store hidden state in RNN.