Struct Conv1dConfig
pub struct Conv1dConfig {
pub channels_in: usize,
pub channels_out: usize,
pub kernel_size: usize,
pub stride: usize,
pub dilation: usize,
pub groups: usize,
pub padding: PaddingConfig1d,
pub bias: bool,
pub initializer: Initializer,
}Expand description
Configuration to create a 1D convolution layer using the init function.
Fields
channels_in: usizeThe number of input channels.
channels_out: usizeThe number of output channels.
kernel_size: usizeThe size of the kernel.
stride: usizeThe stride of the convolution.
dilation: usizeSpacing between kernel elements.
groups: usizeControls the connections between input and output channels.
padding: PaddingConfig1dThe padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
bias: boolIf bias should be added to the output.
initializer: InitializerThe type of function used to initialize neural network parameters
Implementations
impl Conv1dConfig
impl Conv1dConfig
pub fn new(
channels_in: usize,
channels_out: usize,
kernel_size: usize,
) -> Conv1dConfig
pub fn new( channels_in: usize, channels_out: usize, kernel_size: usize, ) -> Conv1dConfig
Create a new instance of the config.
Arguments
Required Arguments
channels_in
The number of input channels.
channels_out
The number of output channels.
kernel_size
The size of the kernel.
Default Arguments
stride
The stride of the convolution.
- Defaults to
"1"
dilation
Spacing between kernel elements.
- Defaults to
"1"
groups
Controls the connections between input and output channels.
- Defaults to
"1"
padding
The padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
- Defaults to
"PaddingConfig1d::Valid"
bias
If bias should be added to the output.
- Defaults to
true
initializer
The type of function used to initialize neural network parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0),fan_out_only:false}"
impl Conv1dConfig
impl Conv1dConfig
pub fn with_stride(self, stride: usize) -> Conv1dConfig
pub fn with_stride(self, stride: usize) -> Conv1dConfig
pub fn with_dilation(self, dilation: usize) -> Conv1dConfig
pub fn with_dilation(self, dilation: usize) -> Conv1dConfig
pub fn with_groups(self, groups: usize) -> Conv1dConfig
pub fn with_groups(self, groups: usize) -> Conv1dConfig
Sets the value for the field groups.
Controls the connections between input and output channels.
- Defaults to
"1"
pub fn with_padding(self, padding: PaddingConfig1d) -> Conv1dConfig
pub fn with_padding(self, padding: PaddingConfig1d) -> Conv1dConfig
Sets the value for the field padding.
The padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
- Defaults to
"PaddingConfig1d::Valid"
pub fn with_bias(self, bias: bool) -> Conv1dConfig
pub fn with_bias(self, bias: bool) -> Conv1dConfig
pub fn with_initializer(self, initializer: Initializer) -> Conv1dConfig
pub fn with_initializer(self, initializer: Initializer) -> Conv1dConfig
Sets the value for the field initializer.
The type of function used to initialize neural network parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0),fan_out_only:false}"
impl Conv1dConfig
impl Conv1dConfig