Struct Conv2dConfig
pub struct Conv2dConfig {
pub channels: [usize; 2],
pub kernel_size: [usize; 2],
pub stride: [usize; 2],
pub dilation: [usize; 2],
pub groups: usize,
pub padding: PaddingConfig2d,
pub bias: bool,
pub initializer: Initializer,
}Expand description
Configuration to create a 2D convolution layer, using the init function.
Fields
channels: [usize; 2]The number of channels.
kernel_size: [usize; 2]The size of the kernel.
stride: [usize; 2]The stride of the convolution.
dilation: [usize; 2]Spacing between kernel elements.
groups: usizeControls the connections between input and output channels.
padding: PaddingConfig2dThe padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
bias: boolIf bias should be added to the output.
initializer: InitializerThe type of function used to initialize neural network parameters
Implementations
impl Conv2dConfig
impl Conv2dConfig
pub fn new(channels: [usize; 2], kernel_size: [usize; 2]) -> Conv2dConfig
pub fn new(channels: [usize; 2], kernel_size: [usize; 2]) -> Conv2dConfig
Create a new instance of the config.
Arguments
Required Arguments
channels
The number of channels.
kernel_size
The size of the kernel.
Default Arguments
stride
The stride of the convolution.
- Defaults to
"[1, 1]"
dilation
Spacing between kernel elements.
- Defaults to
"[1, 1]"
groups
Controls the connections between input and output channels.
- Defaults to
"1"
padding
The padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
- Defaults to
"PaddingConfig2d::Valid"
bias
If bias should be added to the output.
- Defaults to
true
initializer
The type of function used to initialize neural network parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0),fan_out_only:false}"
impl Conv2dConfig
impl Conv2dConfig
pub fn with_stride(self, stride: [usize; 2]) -> Conv2dConfig
pub fn with_stride(self, stride: [usize; 2]) -> Conv2dConfig
pub fn with_dilation(self, dilation: [usize; 2]) -> Conv2dConfig
pub fn with_dilation(self, dilation: [usize; 2]) -> Conv2dConfig
pub fn with_groups(self, groups: usize) -> Conv2dConfig
pub fn with_groups(self, groups: usize) -> Conv2dConfig
Sets the value for the field groups.
Controls the connections between input and output channels.
- Defaults to
"1"
pub fn with_padding(self, padding: PaddingConfig2d) -> Conv2dConfig
pub fn with_padding(self, padding: PaddingConfig2d) -> Conv2dConfig
Sets the value for the field padding.
The padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
- Defaults to
"PaddingConfig2d::Valid"
pub fn with_bias(self, bias: bool) -> Conv2dConfig
pub fn with_bias(self, bias: bool) -> Conv2dConfig
pub fn with_initializer(self, initializer: Initializer) -> Conv2dConfig
pub fn with_initializer(self, initializer: Initializer) -> Conv2dConfig
Sets the value for the field initializer.
The type of function used to initialize neural network parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0),fan_out_only:false}"
impl Conv2dConfig
impl Conv2dConfig