Struct ConvTranspose2dConfig
pub struct ConvTranspose2dConfig {
pub channels: [usize; 2],
pub kernel_size: [usize; 2],
pub stride: [usize; 2],
pub dilation: [usize; 2],
pub groups: usize,
pub padding: [usize; 2],
pub padding_out: [usize; 2],
pub bias: bool,
pub initializer: Initializer,
}Expand description
Configuration to create an 2D transposed convolution layer using the init function.
Fields
channels: [usize; 2]The number of channels.
kernel_size: [usize; 2]The size of the kernel.
stride: [usize; 2]The stride of the convolution.
dilation: [usize; 2]Spacing between kernel elements.
groups: usizeControls the connections between input and output channels.
padding: [usize; 2]The padding configuration.
padding_out: [usize; 2]The padding output configuration.
bias: boolIf bias should be added to the output.
initializer: InitializerThe type of function used to initialize neural network parameters
Implementations
impl ConvTranspose2dConfig
impl ConvTranspose2dConfig
pub fn new(
channels: [usize; 2],
kernel_size: [usize; 2],
) -> ConvTranspose2dConfig
pub fn new( channels: [usize; 2], kernel_size: [usize; 2], ) -> ConvTranspose2dConfig
Create a new instance of the config.
Arguments
Required Arguments
channels
The number of channels.
kernel_size
The size of the kernel.
Default Arguments
stride
The stride of the convolution.
- Defaults to
"[1, 1]"
dilation
Spacing between kernel elements.
- Defaults to
"[1, 1]"
groups
Controls the connections between input and output channels.
- Defaults to
"1"
padding
The padding configuration.
- Defaults to
"[0, 0]"
padding_out
The padding output configuration.
- Defaults to
"[0, 0]"
bias
If bias should be added to the output.
- Defaults to
true
initializer
The type of function used to initialize neural network parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0),fan_out_only:false}"
impl ConvTranspose2dConfig
impl ConvTranspose2dConfig
pub fn with_stride(self, stride: [usize; 2]) -> ConvTranspose2dConfig
pub fn with_stride(self, stride: [usize; 2]) -> ConvTranspose2dConfig
pub fn with_dilation(self, dilation: [usize; 2]) -> ConvTranspose2dConfig
pub fn with_dilation(self, dilation: [usize; 2]) -> ConvTranspose2dConfig
pub fn with_groups(self, groups: usize) -> ConvTranspose2dConfig
pub fn with_groups(self, groups: usize) -> ConvTranspose2dConfig
Sets the value for the field groups.
Controls the connections between input and output channels.
- Defaults to
"1"
pub fn with_padding(self, padding: [usize; 2]) -> ConvTranspose2dConfig
pub fn with_padding(self, padding: [usize; 2]) -> ConvTranspose2dConfig
pub fn with_padding_out(self, padding_out: [usize; 2]) -> ConvTranspose2dConfig
pub fn with_padding_out(self, padding_out: [usize; 2]) -> ConvTranspose2dConfig
pub fn with_bias(self, bias: bool) -> ConvTranspose2dConfig
pub fn with_bias(self, bias: bool) -> ConvTranspose2dConfig
pub fn with_initializer(self, initializer: Initializer) -> ConvTranspose2dConfig
pub fn with_initializer(self, initializer: Initializer) -> ConvTranspose2dConfig
Sets the value for the field initializer.
The type of function used to initialize neural network parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0),fan_out_only:false}"
impl ConvTranspose2dConfig
impl ConvTranspose2dConfig
pub fn init<B>(
&self,
device: &<B as BackendTypes>::Device,
) -> ConvTranspose2d<B>where
B: Backend,
pub fn init<B>(
&self,
device: &<B as BackendTypes>::Device,
) -> ConvTranspose2d<B>where
B: Backend,
Initialize a new conv transpose 2d module.