Struct DeformConv2dConfig
pub struct DeformConv2dConfig {
pub channels: [usize; 2],
pub kernel_size: [usize; 2],
pub stride: [usize; 2],
pub dilation: [usize; 2],
pub weight_groups: usize,
pub offset_groups: usize,
pub padding: PaddingConfig2d,
pub bias: bool,
pub initializer: Initializer,
}Expand description
Configuration to create a deformable 2D convolution layer, using the init function.
Fields
channels: [usize; 2]The number of channels.
kernel_size: [usize; 2]The size of the kernel.
stride: [usize; 2]The stride of the convolution.
dilation: [usize; 2]Spacing between kernel elements.
weight_groups: usizeControls the connections between input and output channels.
offset_groups: usizeOffset groups.
padding: PaddingConfig2dThe padding configuration.
Warning
Only symmetric padding is currently supported. As such, using Same padding with an even kernel
size is not supported as it will not produce the same output size.
bias: boolIf bias should be added to the output.
initializer: InitializerThe type of function used to initialize neural network parameters
Implementations
impl DeformConv2dConfig
impl DeformConv2dConfig
pub fn new(channels: [usize; 2], kernel_size: [usize; 2]) -> DeformConv2dConfig
pub fn new(channels: [usize; 2], kernel_size: [usize; 2]) -> DeformConv2dConfig
Create a new instance of the config.
Arguments
Required Arguments
channels
The number of channels.
kernel_size
The size of the kernel.
Default Arguments
stride
The stride of the convolution.
- Defaults to
"[1, 1]"
dilation
Spacing between kernel elements.
- Defaults to
"[1, 1]"
weight_groups
Controls the connections between input and output channels.
- Defaults to
"1"
offset_groups
Offset groups.
- Defaults to
"1"
padding
The padding configuration.
Warning
Only symmetric padding is currently supported. As such, using Same padding with an even kernel
size is not supported as it will not produce the same output size.
- Defaults to
"PaddingConfig2d::Valid"
bias
If bias should be added to the output.
- Defaults to
true
initializer
The type of function used to initialize neural network parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0),fan_out_only:false}"
impl DeformConv2dConfig
impl DeformConv2dConfig
pub fn with_stride(self, stride: [usize; 2]) -> DeformConv2dConfig
pub fn with_stride(self, stride: [usize; 2]) -> DeformConv2dConfig
pub fn with_dilation(self, dilation: [usize; 2]) -> DeformConv2dConfig
pub fn with_dilation(self, dilation: [usize; 2]) -> DeformConv2dConfig
pub fn with_weight_groups(self, weight_groups: usize) -> DeformConv2dConfig
pub fn with_weight_groups(self, weight_groups: usize) -> DeformConv2dConfig
Sets the value for the field weight_groups.
Controls the connections between input and output channels.
- Defaults to
"1"
pub fn with_offset_groups(self, offset_groups: usize) -> DeformConv2dConfig
pub fn with_offset_groups(self, offset_groups: usize) -> DeformConv2dConfig
pub fn with_padding(self, padding: PaddingConfig2d) -> DeformConv2dConfig
pub fn with_padding(self, padding: PaddingConfig2d) -> DeformConv2dConfig
pub fn with_bias(self, bias: bool) -> DeformConv2dConfig
pub fn with_bias(self, bias: bool) -> DeformConv2dConfig
pub fn with_initializer(self, initializer: Initializer) -> DeformConv2dConfig
pub fn with_initializer(self, initializer: Initializer) -> DeformConv2dConfig
Sets the value for the field initializer.
The type of function used to initialize neural network parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0),fan_out_only:false}"
impl DeformConv2dConfig
impl DeformConv2dConfig
pub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> DeformConv2d<B>where
B: Backend,
pub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> DeformConv2d<B>where
B: Backend,
Initialize a new DeformConv2d module.