#[non_exhaustive]pub enum NormalizationConfig {
Batch(BatchNormConfig),
Group(GroupNormConfig),
Instance(InstanceNormConfig),
Layer(LayerNormConfig),
Rms(RmsNormConfig),
}Expand description
[‘Normalization’] Configuration.
The enum is non-exhaustive to prepare for future additions.
Can be used as a generic configuration for normalization layers:
- Construct a config with arbitrary input features (we suggest
0). - Clone and match that config to the target input layer,
using the
NormalizationConfig::with_num_features()method.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Batch(BatchNormConfig)
[‘BatchNorm’] Configuration.
Group(GroupNormConfig)
[‘GroupNorm’] Configuration.
Instance(InstanceNormConfig)
[‘InstanceNorm’] Configuration.
Layer(LayerNormConfig)
[‘LayerNorm’] Configuration.
Rms(RmsNormConfig)
[‘RmsNorm’] Configuration.
Implementations
Sourceimpl NormalizationConfig
impl NormalizationConfig
Sourcepub fn init<B>(&self, device: &<B as Backend>::Device) -> Normalization<B>where
B: Backend,
pub fn init<B>(&self, device: &<B as Backend>::Device) -> Normalization<B>where
B: Backend,
Initialize a [‘Norm’] layer.
Sourcepub fn with_num_features(self, num_features: usize) -> NormalizationConfig
pub fn with_num_features(self, num_features: usize) -> NormalizationConfig
Set the number of features.
Sourcepub fn num_features(&self) -> usize
pub fn num_features(&self) -> usize
Get the number of features.