LocalResponseNorm

Struct LocalResponseNorm 

pub struct LocalResponseNorm { /* private fields */ }
Applies Local Response Normalization as described in ImageNet Classification with Deep Convolutional Neural Networks.

Y = X / (k + (alpha / size) * sum(X^2))^beta

Where the sum is computed over a sliding window of size channels.

For odd size, the window is centered on each channel position. For even size, the window uses asymmetric padding and includes the current channel plus one extra channel on the positive side.

Should be created using LocalResponseNormConfig.

Implementations

Source

impl LocalResponseNorm

pub fn forward<B, const D: usize>(&self, input: Tensor<B, D>) -> Tensor<B, D>
where B: Backend,

Applies Local Response Normalization on the input tensor.

Shapes
  • input: [N, C, D1, D2, ..., Dk] (rank >= 3)
  • output: same shape as input
Panics

Panics if the input tensor rank is less than 3.