AvgPool2dConfig

Struct AvgPool2dConfig 

pub struct AvgPool2dConfig {
    pub kernel_size: [usize; 2],
    pub strides: [usize; 2],
    pub padding: PaddingConfig2d,
    pub count_include_pad: bool,
    pub ceil_mode: bool,
}
Configuration to create a 2D avg pooling layer using the init function.

Fields

kernel_size: [usize; 2]

The size of the kernel.

strides: [usize; 2]

The strides.

padding: PaddingConfig2d

The padding configuration.

Supports symmetric and asymmetric padding. Same padding with even kernel sizes will automatically use asymmetric padding to preserve input dimensions.

count_include_pad: bool

If the padding is counted in the denominator when computing the average.

ceil_mode: bool

If true, use ceiling instead of floor for output size calculation.

Implementations



impl AvgPool2dConfig

pub fn new(kernel_size: [usize; 2]) -> AvgPool2dConfig

Create a new instance of the config.

Arguments
Required Arguments
kernel_size

The size of the kernel.

Default Arguments
strides

The strides.

  • Defaults to "kernel_size"
padding

The padding configuration.

Supports symmetric and asymmetric padding. Same padding with even kernel sizes will automatically use asymmetric padding to preserve input dimensions.

  • Defaults to "PaddingConfig2d::Valid"
count_include_pad

If the padding is counted in the denominator when computing the average.

  • Defaults to "true"
ceil_mode

If true, use ceiling instead of floor for output size calculation.

  • Defaults to "false"


impl AvgPool2dConfig

pub fn with_strides(self, strides: [usize; 2]) -> AvgPool2dConfig

Sets the value for the field strides.

The strides.

  • Defaults to "kernel_size"

pub fn with_padding(self, padding: PaddingConfig2d) -> AvgPool2dConfig

Sets the value for the field padding.

The padding configuration.

Supports symmetric and asymmetric padding. Same padding with even kernel sizes will automatically use asymmetric padding to preserve input dimensions.

  • Defaults to "PaddingConfig2d::Valid"

pub fn with_count_include_pad(self, count_include_pad: bool) -> AvgPool2dConfig

Sets the value for the field count_include_pad.

If the padding is counted in the denominator when computing the average.

  • Defaults to "true"

pub fn with_ceil_mode(self, ceil_mode: bool) -> AvgPool2dConfig

Sets the value for the field ceil_mode.

If true, use ceiling instead of floor for output size calculation.

  • Defaults to "false"


impl AvgPool2dConfig

pub fn init(&self) -> AvgPool2d

Initialize a new avg pool 2d module.