Struct GroupNormConfig
pub struct GroupNormConfig {
pub num_groups: usize,
pub num_channels: usize,
pub epsilon: f64,
pub affine: bool,
}Expand description
Configuration to create a GroupNorm layer using the init function.
Fields
num_groups: usizeThe number of groups to separate the channels into
num_channels: usizeThe number of channels expected in the input
epsilon: f64A value required for numerical stability. Default: 1e-5
affine: boolA boolean value that when set to true, this module has learnable
per-channel affine parameters initialized to ones (for weights)
and zeros (for biases). Default: true
Implementations
impl GroupNormConfig
impl GroupNormConfig
pub fn new(num_groups: usize, num_channels: usize) -> GroupNormConfig
pub fn new(num_groups: usize, num_channels: usize) -> GroupNormConfig
Create a new instance of the config.
Arguments
Required Arguments
num_groups
The number of groups to separate the channels into
num_channels
The number of channels expected in the input
Default Arguments
epsilon
A value required for numerical stability. Default: 1e-5
- Defaults to
1e-5
affine
A boolean value that when set to true, this module has learnable
per-channel affine parameters initialized to ones (for weights)
and zeros (for biases). Default: true
- Defaults to
true
impl GroupNormConfig
impl GroupNormConfig
pub fn with_epsilon(self, epsilon: f64) -> GroupNormConfig
pub fn with_epsilon(self, epsilon: f64) -> GroupNormConfig
Sets the value for the field epsilon.
A value required for numerical stability. Default: 1e-5
- Defaults to
1e-5
pub fn with_affine(self, affine: bool) -> GroupNormConfig
pub fn with_affine(self, affine: bool) -> GroupNormConfig
Sets the value for the field affine.
A boolean value that when set to true, this module has learnable
per-channel affine parameters initialized to ones (for weights)
and zeros (for biases). Default: true
- Defaults to
true
impl GroupNormConfig
impl GroupNormConfig
pub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> GroupNorm<B>where
B: Backend,
pub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> GroupNorm<B>where
B: Backend,
Initialize a new group norm module.