pub struct GroupNormRecord<B>where
B: Backend,{
pub gamma: <Option<Param<Tensor<B, 1>>> as Module<B>>::Record,
pub beta: <Option<Param<Tensor<B, 1>>> as Module<B>>::Record,
pub num_groups: EmptyRecord,
pub num_channels: EmptyRecord,
pub epsilon: EmptyRecord,
pub affine: EmptyRecord,
}Expand description
The record type for the module.
Fields
gamma: <Option<Param<Tensor<B, 1>>> as Module<B>>::RecordThe module record associative type.
beta: <Option<Param<Tensor<B, 1>>> as Module<B>>::RecordThe module record associative type.
num_groups: EmptyRecordnum_channels: EmptyRecordepsilon: EmptyRecordaffine: EmptyRecordTrait Implementations
Sourceimpl<B> Record<B> for GroupNormRecord<B>where
B: Backend,
impl<B> Record<B> for GroupNormRecord<B>where
B: Backend,
Sourcetype Item<S: PrecisionSettings> = GroupNormRecordItem<B, S>
type Item<S: PrecisionSettings> = GroupNormRecordItem<B, S>
Type of the item that can be serialized and deserialized.
Sourcefn into_item<S>(self) -> <GroupNormRecord<B> as Record<B>>::Item<S>where
S: PrecisionSettings,
fn into_item<S>(self) -> <GroupNormRecord<B> as Record<B>>::Item<S>where
S: PrecisionSettings,
Convert the current record into the corresponding item that follows the given settings.
Sourcefn from_item<S>(
item: <GroupNormRecord<B> as Record<B>>::Item<S>,
device: &<B as BackendTypes>::Device,
) -> GroupNormRecord<B>where
S: PrecisionSettings,
fn from_item<S>(
item: <GroupNormRecord<B> as Record<B>>::Item<S>,
device: &<B as BackendTypes>::Device,
) -> GroupNormRecord<B>where
S: PrecisionSettings,
Convert the given item into a record.