Struct LinearConfig
pub struct LinearConfig {
pub d_input: usize,
pub d_output: usize,
pub bias: bool,
pub initializer: Initializer,
pub layout: LinearLayout,
}Expand description
Configuration to create a Linear layer using the init function.
Fields
d_input: usizeThe size of the input features.
d_output: usizeThe size of the output features.
bias: boolIf a bias should be applied during the linear transformation.
initializer: InitializerThe type of function used to initialize neural network parameters
layout: LinearLayoutThe layout in which the linear parameters are stored.
Implementations
impl LinearConfig
impl LinearConfig
pub fn new(d_input: usize, d_output: usize) -> LinearConfig
pub fn new(d_input: usize, d_output: usize) -> LinearConfig
Create a new instance of the config.
Arguments
Required Arguments
d_input
The size of the input features.
d_output
The size of the output features.
Default Arguments
bias
If a bias should be applied during the linear transformation.
- Defaults to
true
initializer
The type of function used to initialize neural network parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0), fan_out_only:false}"
layout
The layout in which the linear parameters are stored.
- Defaults to
"LinearLayout::Row"
impl LinearConfig
impl LinearConfig
pub fn with_bias(self, bias: bool) -> LinearConfig
pub fn with_bias(self, bias: bool) -> LinearConfig
Sets the value for the field bias.
If a bias should be applied during the linear transformation.
- Defaults to
true
pub fn with_initializer(self, initializer: Initializer) -> LinearConfig
pub fn with_initializer(self, initializer: Initializer) -> LinearConfig
Sets the value for the field initializer.
The type of function used to initialize neural network parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0), fan_out_only:false}"
pub fn with_layout(self, layout: LinearLayout) -> LinearConfig
pub fn with_layout(self, layout: LinearLayout) -> LinearConfig
Sets the value for the field layout.
The layout in which the linear parameters are stored.
- Defaults to
"LinearLayout::Row"
impl LinearConfig
impl LinearConfig