Struct PositionWiseFeedForward
pub struct PositionWiseFeedForward<B>where
B: Backend,{
pub linear_inner: Linear<B>,
pub linear_outer: Linear<B>,
pub dropout: Dropout,
pub activation: Activation<B>,
}Expand description
Applies the position-wise feed-forward network to the input tensor from the paper Attention Is All You Need.
Params
- linear inner: Linear layer with
d_modelinput features andd_ffoutput features. - linear outer: Linear layer with
d_ffinput features andd_modeloutput features.
FFN(x) = max(0, xW1 + b1)W2 + b2
Should be created using PositionWiseFeedForwardConfig
Notes
The activation field is currently marked #[module(skip)] for backward
compatibility with records saved before this field was introduced (when
the activation was always Gelu and had no state). This means activation
state is not persisted when saving or loading records.
For stateless activations (GELU, ReLU, etc.) this has no effect.
If you are using SwiGLU, its learnable parameters will not be saved or
loaded correctly.
Fields
linear_inner: Linear<B>Linear layer with d_model input features and d_ff output features.
linear_outer: Linear<B>Linear layer with d_ff input features and d_model output features.
dropout: DropoutDropout layer.
activation: Activation<B>Activation function.
Implementations