Struct PositionWiseFeedForwardConfig
pub struct PositionWiseFeedForwardConfig {
pub d_model: usize,
pub d_ff: usize,
pub dropout: f64,
pub initializer: Initializer,
pub activation: ActivationConfig,
}Expand description
Configuration to create a position-wise feed-forward layer using the init function.
Fields
d_model: usizeThe size of the input and output features.
d_ff: usizeThe size of the hidden inner features.
dropout: f64The dropout rate. Default: 0.1
initializer: InitializerThe type of function used to initialize neural network parameters
activation: ActivationConfigThe activation function used between the two linear layers. Default: Gelu
Implementations
impl PositionWiseFeedForwardConfig
impl PositionWiseFeedForwardConfig
pub fn new(d_model: usize, d_ff: usize) -> PositionWiseFeedForwardConfig
pub fn new(d_model: usize, d_ff: usize) -> PositionWiseFeedForwardConfig
Create a new instance of the config.
Arguments
Required Arguments
d_model
The size of the input and output features.
d_ff
The size of the hidden inner features.
Default Arguments
dropout
The dropout rate. Default: 0.1
- Defaults to
0.1
initializer
The type of function used to initialize neural network parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0), fan_out_only:false}"
activation
The activation function used between the two linear layers. Default: Gelu
- Defaults to
"ActivationConfig::Gelu"
impl PositionWiseFeedForwardConfig
impl PositionWiseFeedForwardConfig
pub fn with_dropout(self, dropout: f64) -> PositionWiseFeedForwardConfig
pub fn with_dropout(self, dropout: f64) -> PositionWiseFeedForwardConfig
pub fn with_initializer(
self,
initializer: Initializer,
) -> PositionWiseFeedForwardConfig
pub fn with_initializer( self, initializer: Initializer, ) -> PositionWiseFeedForwardConfig
Sets the value for the field initializer.
The type of function used to initialize neural network parameters
- Defaults to
"Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0), fan_out_only:false}"
pub fn with_activation(
self,
activation: ActivationConfig,
) -> PositionWiseFeedForwardConfig
pub fn with_activation( self, activation: ActivationConfig, ) -> PositionWiseFeedForwardConfig
Sets the value for the field activation.
The activation function used between the two linear layers. Default: Gelu
- Defaults to
"ActivationConfig::Gelu"
impl PositionWiseFeedForwardConfig
impl PositionWiseFeedForwardConfig
pub fn init<B>(
&self,
device: &<B as BackendTypes>::Device,
) -> PositionWiseFeedForward<B>where
B: Backend,
pub fn init<B>(
&self,
device: &<B as BackendTypes>::Device,
) -> PositionWiseFeedForward<B>where
B: Backend,
Initialize a new position-wise feed-forward module.