pub struct TransformerEncoderRecord<B>where
B: Backend,{
pub layers: <Vec<TransformerEncoderLayer<B>> as Module<B>>::Record,
pub d_model: EmptyRecord,
pub d_ff: EmptyRecord,
pub n_heads: EmptyRecord,
pub n_layers: EmptyRecord,
pub dropout: EmptyRecord,
pub norm_first: EmptyRecord,
pub quiet_softmax: EmptyRecord,
}Expand description
The record type for the module.
Fields
layers: <Vec<TransformerEncoderLayer<B>> as Module<B>>::RecordThe module record associative type.
d_model: EmptyRecordd_ff: EmptyRecordn_heads: EmptyRecordn_layers: EmptyRecorddropout: EmptyRecordnorm_first: EmptyRecordquiet_softmax: EmptyRecordTrait Implementations
Sourceimpl<B> Record<B> for TransformerEncoderRecord<B>where
B: Backend,
impl<B> Record<B> for TransformerEncoderRecord<B>where
B: Backend,
Sourcetype Item<S: PrecisionSettings> = TransformerEncoderRecordItem<B, S>
type Item<S: PrecisionSettings> = TransformerEncoderRecordItem<B, S>
Type of the item that can be serialized and deserialized.
Sourcefn into_item<S>(self) -> <TransformerEncoderRecord<B> as Record<B>>::Item<S>where
S: PrecisionSettings,
fn into_item<S>(self) -> <TransformerEncoderRecord<B> as Record<B>>::Item<S>where
S: PrecisionSettings,
Convert the current record into the corresponding item that follows the given settings.
Sourcefn from_item<S>(
item: <TransformerEncoderRecord<B> as Record<B>>::Item<S>,
device: &<B as BackendTypes>::Device,
) -> TransformerEncoderRecord<B>where
S: PrecisionSettings,
fn from_item<S>(
item: <TransformerEncoderRecord<B> as Record<B>>::Item<S>,
device: &<B as BackendTypes>::Device,
) -> TransformerEncoderRecord<B>where
S: PrecisionSettings,
Convert the given item into a record.