Struct BiGruConfig
pub struct BiGruConfig {
pub d_input: usize,
pub d_hidden: usize,
pub bias: bool,
pub reset_after: bool,
pub initializer: Initializer,
pub batch_first: bool,
pub gate_activation: ActivationConfig,
pub hidden_activation: ActivationConfig,
pub clip: Option<f64>,
}Expand description
Configuration to create a BiGru module using the init function.
Fields
d_input: usizeThe size of the input features.
The size of the hidden state.
bias: boolIf a bias should be applied during the BiGru transformation.
reset_after: boolIf reset gate should be applied after weight multiplication.
initializer: InitializerBiGru initializer
batch_first: boolIf true, the input tensor is expected to be [batch_size, seq_length, input_size].
If false, the input tensor is expected to be [seq_length, batch_size, input_size].
gate_activation: ActivationConfigActivation function for the update and reset gates.
Activation function for the new/candidate gate.
clip: Option<f64>Optional hidden state clip threshold.
Implementations
impl BiGruConfig
impl BiGruConfig
pub fn new(d_input: usize, d_hidden: usize, bias: bool) -> BiGruConfig
pub fn new(d_input: usize, d_hidden: usize, bias: bool) -> BiGruConfig
Create a new instance of the config.
Arguments
Required Arguments
d_input
The size of the input features.
d_hidden
The size of the hidden state.
bias
If a bias should be applied during the BiGru transformation.
Optional Arguments
clip
Optional hidden state clip threshold.
- Defaults to
None
Default Arguments
reset_after
If reset gate should be applied after weight multiplication.
- Defaults to
"true"
initializer
BiGru initializer
- Defaults to
"Initializer::XavierNormal{gain:1.0}"
batch_first
If true, the input tensor is expected to be [batch_size, seq_length, input_size].
If false, the input tensor is expected to be [seq_length, batch_size, input_size].
- Defaults to
true
gate_activation
Activation function for the update and reset gates.
- Defaults to
"ActivationConfig::Sigmoid"
hidden_activation
Activation function for the new/candidate gate.
- Defaults to
"ActivationConfig::Tanh"
impl BiGruConfig
impl BiGruConfig
pub fn with_reset_after(self, reset_after: bool) -> BiGruConfig
pub fn with_reset_after(self, reset_after: bool) -> BiGruConfig
Sets the value for the field reset_after.
If reset gate should be applied after weight multiplication.
- Defaults to
"true"
pub fn with_initializer(self, initializer: Initializer) -> BiGruConfig
pub fn with_initializer(self, initializer: Initializer) -> BiGruConfig
Sets the value for the field initializer.
BiGru initializer
- Defaults to
"Initializer::XavierNormal{gain:1.0}"
pub fn with_batch_first(self, batch_first: bool) -> BiGruConfig
pub fn with_batch_first(self, batch_first: bool) -> BiGruConfig
Sets the value for the field batch_first.
If true, the input tensor is expected to be [batch_size, seq_length, input_size].
If false, the input tensor is expected to be [seq_length, batch_size, input_size].
- Defaults to
true
pub fn with_gate_activation(
self,
gate_activation: ActivationConfig,
) -> BiGruConfig
pub fn with_gate_activation( self, gate_activation: ActivationConfig, ) -> BiGruConfig
Sets the value for the field gate_activation.
Activation function for the update and reset gates.
- Defaults to
"ActivationConfig::Sigmoid"
Sets the value for the field hidden_activation.
Activation function for the new/candidate gate.
- Defaults to
"ActivationConfig::Tanh"
pub fn with_clip(self, clip: Option<f64>) -> BiGruConfig
pub fn with_clip(self, clip: Option<f64>) -> BiGruConfig
impl BiGruConfig
impl BiGruConfig
pub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> BiGru<B>where
B: Backend,
pub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> BiGru<B>where
B: Backend,
Initialize a new Bidirectional GRU module.