pub struct BiLstmConfig {
pub d_input: usize,
pub d_hidden: usize,
pub bias: bool,
pub initializer: Initializer,
pub batch_first: bool,
pub clip: Option<f64>,
pub input_forget: bool,
pub gate_activation: ActivationConfig,
pub cell_activation: ActivationConfig,
pub hidden_activation: ActivationConfig,
}Expand description
Configuration to create a BiLstm module using the init function.
Fields
d_input: usizeThe size of the input features.
The size of the hidden state.
bias: boolIf a bias should be applied during the BiLstm transformation.
initializer: InitializerBiLstm initializer
batch_first: boolIf true, the input tensor is expected to be [batch_size, seq_length, input_size].
If false, the input tensor is expected to be [seq_length, batch_size, input_size].
clip: Option<f64>Optional cell state clip threshold.
input_forget: boolIf true, couples the input and forget gates.
gate_activation: ActivationConfigActivation function for the input, forget, and output gates.
cell_activation: ActivationConfigActivation function for the cell gate (candidate cell state).
Activation function applied to the cell state before computing hidden output.
Implementations
Sourceimpl BiLstmConfig
impl BiLstmConfig
Sourcepub fn new(d_input: usize, d_hidden: usize, bias: bool) -> BiLstmConfig
pub fn new(d_input: usize, d_hidden: usize, bias: bool) -> BiLstmConfig
Create a new instance of the config.
Arguments
Required Arguments
d_input
The size of the input features.
d_hidden
The size of the hidden state.
bias
If a bias should be applied during the BiLstm transformation.
Optional Arguments
clip
Optional cell state clip threshold.
- Defaults to
None
Default Arguments
initializer
BiLstm initializer
- Defaults to
"Initializer::XavierNormal{gain:1.0}"
batch_first
If true, the input tensor is expected to be [batch_size, seq_length, input_size].
If false, the input tensor is expected to be [seq_length, batch_size, input_size].
- Defaults to
true
input_forget
If true, couples the input and forget gates.
- Defaults to
false
gate_activation
Activation function for the input, forget, and output gates.
- Defaults to
"ActivationConfig::Sigmoid"
cell_activation
Activation function for the cell gate (candidate cell state).
- Defaults to
"ActivationConfig::Tanh"
hidden_activation
Activation function applied to the cell state before computing hidden output.
- Defaults to
"ActivationConfig::Tanh"
Sourceimpl BiLstmConfig
impl BiLstmConfig
Sourcepub fn with_initializer(self, initializer: Initializer) -> BiLstmConfig
pub fn with_initializer(self, initializer: Initializer) -> BiLstmConfig
Sets the value for the field initializer.
BiLstm initializer
- Defaults to
"Initializer::XavierNormal{gain:1.0}"
Sourcepub fn with_batch_first(self, batch_first: bool) -> BiLstmConfig
pub fn with_batch_first(self, batch_first: bool) -> BiLstmConfig
Sets the value for the field batch_first.
If true, the input tensor is expected to be [batch_size, seq_length, input_size].
If false, the input tensor is expected to be [seq_length, batch_size, input_size].
- Defaults to
true
Sourcepub fn with_input_forget(self, input_forget: bool) -> BiLstmConfig
pub fn with_input_forget(self, input_forget: bool) -> BiLstmConfig
Sets the value for the field input_forget.
If true, couples the input and forget gates.
- Defaults to
false
Sourcepub fn with_gate_activation(
self,
gate_activation: ActivationConfig,
) -> BiLstmConfig
pub fn with_gate_activation( self, gate_activation: ActivationConfig, ) -> BiLstmConfig
Sets the value for the field gate_activation.
Activation function for the input, forget, and output gates.
- Defaults to
"ActivationConfig::Sigmoid"
Sourcepub fn with_cell_activation(
self,
cell_activation: ActivationConfig,
) -> BiLstmConfig
pub fn with_cell_activation( self, cell_activation: ActivationConfig, ) -> BiLstmConfig
Sets the value for the field cell_activation.
Activation function for the cell gate (candidate cell state).
- Defaults to
"ActivationConfig::Tanh"
Sets the value for the field hidden_activation.
Activation function applied to the cell state before computing hidden output.
- Defaults to
"ActivationConfig::Tanh"
Sourceimpl BiLstmConfig
impl BiLstmConfig
Sourcepub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> BiLstm<B>where
B: Backend,
pub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> BiLstm<B>where
B: Backend,
Initialize a new Bidirectional LSTM module.