pub struct BiRnn<B>where
B: Backend,{
pub forward: Rnn<B>,
pub reverse: Rnn<B>,
pub d_hidden: usize,
pub batch_first: bool,
}Expand description
The BiRnn module. This implementation is for Bidirectional RNN. Should be created with BiRnnConfig.
Fields
forward: Rnn<B>RNN for the forward direction.
reverse: Rnn<B>RNN for the reverse direction.
The size of the hidden state.
batch_first: boolIf true, input is [batch_size, seq_length, input_size].
If false, input is [seq_length, batch_size, input_size].
Implementations
Sourceimpl<B> BiRnn<B>where
B: Backend,
impl<B> BiRnn<B>where
B: Backend,
Sourcepub fn forward(
&self,
batched_input: Tensor<B, 3>,
state: Option<RnnState<B, 3>>,
) -> (Tensor<B, 3>, RnnState<B, 3>)
pub fn forward( &self, batched_input: Tensor<B, 3>, state: Option<RnnState<B, 3>>, ) -> (Tensor<B, 3>, RnnState<B, 3>)
Applies the forward pass on the input tensor. This Bidirectional RNN implementation returns the state for each element in a sequence (i.e., across seq_length) and a final state.
Parameters:
- batched_input: The input tensor of shape:
[batch_size, sequence_length, input_size]ifbatch_firstis true (default)[sequence_length, batch_size, input_size]ifbatch_firstis false
- state: An optional
RnnStaterepresenting the hidden state. Each state tensor has shape[2, batch_size, hidden_size]. If no initial state is provided, these tensors are initialized to zeros.
Returns:
- output: A tensor represents the output features of RNN. Shape:
[batch_size, sequence_length, hidden_size * 2]ifbatch_firstis true[sequence_length, batch_size, hidden_size * 2]ifbatch_firstis false
- state: A
RnnStaterepresents the final forward and reverse states. Thestate.hiddenhave the shape[2, batch_size, hidden_size].