Struct BiRnnConfig
pub struct BiRnnConfig {
pub d_input: usize,
pub d_hidden: usize,
pub bias: bool,
pub initializer: Initializer,
pub batch_first: bool,
pub clip: Option<f64>,
pub hidden_activation: ActivationConfig,
}Expand description
Configuration to create a BiRnn module using the init function.
Fields
d_input: usizeThe size of the input features.
The size of the hidden state.
bias: boolIf a bias should be applied during the BiRnn transformation.
initializer: InitializerBiRnn initializer
batch_first: boolIf true, the input tensor is expected to be [batch_size, seq_length, input_size].
If false, the input tensor is expected to be [seq_length, batch_size, input_size].
clip: Option<f64>Optional hidden state clip threshold.
Activation function applied to the hidden state before computing hidden output.
Implementations
impl BiRnnConfig
impl BiRnnConfig
pub fn new(d_input: usize, d_hidden: usize, bias: bool) -> BiRnnConfig
pub fn new(d_input: usize, d_hidden: usize, bias: bool) -> BiRnnConfig
Create a new instance of the config.
Arguments
Required Arguments
d_input
The size of the input features.
d_hidden
The size of the hidden state.
bias
If a bias should be applied during the BiRnn transformation.
Optional Arguments
clip
Optional hidden state clip threshold.
- Defaults to
None
Default Arguments
initializer
BiRnn initializer
- Defaults to
"Initializer::XavierNormal{gain:1.0}"
batch_first
If true, the input tensor is expected to be [batch_size, seq_length, input_size].
If false, the input tensor is expected to be [seq_length, batch_size, input_size].
- Defaults to
true
hidden_activation
Activation function applied to the hidden state before computing hidden output.
- Defaults to
"ActivationConfig::Tanh"
impl BiRnnConfig
impl BiRnnConfig
pub fn with_initializer(self, initializer: Initializer) -> BiRnnConfig
pub fn with_initializer(self, initializer: Initializer) -> BiRnnConfig
Sets the value for the field initializer.
BiRnn initializer
- Defaults to
"Initializer::XavierNormal{gain:1.0}"
pub fn with_batch_first(self, batch_first: bool) -> BiRnnConfig
pub fn with_batch_first(self, batch_first: bool) -> BiRnnConfig
Sets the value for the field batch_first.
If true, the input tensor is expected to be [batch_size, seq_length, input_size].
If false, the input tensor is expected to be [seq_length, batch_size, input_size].
- Defaults to
true
Sets the value for the field hidden_activation.
Activation function applied to the hidden state before computing hidden output.
- Defaults to
"ActivationConfig::Tanh"
pub fn with_clip(self, clip: Option<f64>) -> BiRnnConfig
pub fn with_clip(self, clip: Option<f64>) -> BiRnnConfig
impl BiRnnConfig
impl BiRnnConfig
pub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> BiRnn<B>where
B: Backend,
pub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> BiRnn<B>where
B: Backend,
Initialize a new Bidirectional RNN module.