GruConfig

Struct GruConfig 

pub struct GruConfig {
    pub d_input: usize,
    pub d_hidden: usize,
    pub bias: bool,
    pub reset_after: bool,
    pub initializer: Initializer,
    pub gate_activation: ActivationConfig,
    pub hidden_activation: ActivationConfig,
    pub clip: Option<f64>,
}
Configuration to create a gru module using the init function.

Fields

d_input: usize

The size of the input features.

d_hidden: usize

The size of the hidden state.

bias: bool

If a bias should be applied during the Gru transformation.

reset_after: bool

If reset gate should be applied after weight multiplication.

This configuration option controls how the reset gate is applied to the hidden state.

The differing implementations can give slightly different numerical results and have different efficiencies. For more motivation for why the true can be more efficient see Optimizing RNNs with Differentiable Graphs.

To set this field to false use with_reset_after.

initializer: Initializer

Gru initializer

gate_activation: ActivationConfig

Activation function for the update and reset gates. Default is Sigmoid, which is standard for GRU gates.

hidden_activation: ActivationConfig

Activation function for the new/candidate gate. Default is Tanh, which is standard for GRU.

clip: Option<f64>

Optional hidden state clip threshold. If provided, hidden state values are clipped to the range [-clip, +clip] after each timestep. This can help prevent exploding values during inference.

Implementations



impl GruConfig

pub fn new(d_input: usize, d_hidden: usize, bias: bool) -> GruConfig

Create a new instance of the config.

Arguments
Required Arguments
d_input

The size of the input features.

d_hidden

The size of the hidden state.

bias

If a bias should be applied during the Gru transformation.

Optional Arguments
clip

Optional hidden state clip threshold. If provided, hidden state values are clipped to the range [-clip, +clip] after each timestep. This can help prevent exploding values during inference.

  • Defaults to None
Default Arguments
reset_after

If reset gate should be applied after weight multiplication.

This configuration option controls how the reset gate is applied to the hidden state.

The differing implementations can give slightly different numerical results and have different efficiencies. For more motivation for why the true can be more efficient see Optimizing RNNs with Differentiable Graphs.

To set this field to false use with_reset_after.

  • Defaults to "true"
initializer

Gru initializer

  • Defaults to "Initializer::XavierNormal{gain:1.0}"
gate_activation

Activation function for the update and reset gates. Default is Sigmoid, which is standard for GRU gates.

  • Defaults to "ActivationConfig::Sigmoid"
hidden_activation

Activation function for the new/candidate gate. Default is Tanh, which is standard for GRU.

  • Defaults to "ActivationConfig::Tanh"


impl GruConfig

pub fn with_reset_after(self, reset_after: bool) -> GruConfig

Sets the value for the field reset_after.

If reset gate should be applied after weight multiplication.

This configuration option controls how the reset gate is applied to the hidden state.

The differing implementations can give slightly different numerical results and have different efficiencies. For more motivation for why the true can be more efficient see Optimizing RNNs with Differentiable Graphs.

To set this field to false use with_reset_after.

  • Defaults to "true"

pub fn with_initializer(self, initializer: Initializer) -> GruConfig

Sets the value for the field initializer.

Gru initializer

  • Defaults to "Initializer::XavierNormal{gain:1.0}"

pub fn with_gate_activation( self, gate_activation: ActivationConfig, ) -> GruConfig

Sets the value for the field gate_activation.

Activation function for the update and reset gates. Default is Sigmoid, which is standard for GRU gates.

  • Defaults to "ActivationConfig::Sigmoid"

pub fn with_hidden_activation( self, hidden_activation: ActivationConfig, ) -> GruConfig

Sets the value for the field hidden_activation.

Activation function for the new/candidate gate. Default is Tanh, which is standard for GRU.

  • Defaults to "ActivationConfig::Tanh"

pub fn with_clip(self, clip: Option<f64>) -> GruConfig

Sets the value for the field clip.

Optional hidden state clip threshold. If provided, hidden state values are clipped to the range [-clip, +clip] after each timestep. This can help prevent exploding values during inference.

  • Defaults to None


impl GruConfig

pub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> Gru<B>
where B: Backend,

Initialize a new gru module.