RnnConfig

Struct RnnConfig 

pub struct RnnConfig {
    pub d_input: usize,
    pub d_hidden: usize,
    pub bias: bool,
    pub initializer: Initializer,
    pub batch_first: bool,
    pub reverse: bool,
    pub clip: Option<f64>,
    pub hidden_activation: ActivationConfig,
}
Configuration to create a Rnn module using the init function.

Fields

d_input: usize

The size of the input features.

d_hidden: usize

The size of the hidden state.

bias: bool

If a bias should be applied during the Rnn transformation.

initializer: Initializer

Rnn initializer

batch_first: bool

If true, the input tensor is expected to be [batch_size, seq_length, input_size]. If false, the input tensor is expected to be [seq_length, batch_size, input_size].

reverse: bool

If true, process the sequence in reverse order. This is useful for implementing reverse-direction RNNs (e.g., ONNX reverse direction).

clip: Option<f64>

Optional hidden state clip threshold. If provided, hidden state values are clipped to the range [-clip, +clip] after each timestep. This can help prevent exploding values during inference.

hidden_activation: ActivationConfig

Activation function applied to the hidden state before computing hidden output. Default is Tanh, which is standard for Rnn.

Implementations

Source

impl RnnConfig

pub fn new(d_input: usize, d_hidden: usize, bias: bool) -> RnnConfig

Create a new instance of the config.

Arguments
Required Arguments
d_input

The size of the input features.

d_hidden

The size of the hidden state.

bias

If a bias should be applied during the Rnn transformation.

Optional Arguments
clip

Optional hidden state clip threshold. If provided, hidden state values are clipped to the range [-clip, +clip] after each timestep. This can help prevent exploding values during inference.

  • Defaults to None
Default Arguments
initializer

Rnn initializer

  • Defaults to "Initializer::XavierNormal{gain:1.0}"
batch_first

If true, the input tensor is expected to be [batch_size, seq_length, input_size]. If false, the input tensor is expected to be [seq_length, batch_size, input_size].

  • Defaults to true
reverse

If true, process the sequence in reverse order. This is useful for implementing reverse-direction RNNs (e.g., ONNX reverse direction).

  • Defaults to false
hidden_activation

Activation function applied to the hidden state before computing hidden output. Default is Tanh, which is standard for Rnn.

  • Defaults to "ActivationConfig::Tanh"
Source

impl RnnConfig

pub fn with_initializer(self, initializer: Initializer) -> RnnConfig

Sets the value for the field initializer.

Rnn initializer

  • Defaults to "Initializer::XavierNormal{gain:1.0}"
pub fn with_batch_first(self, batch_first: bool) -> RnnConfig

Sets the value for the field batch_first.

If true, the input tensor is expected to be [batch_size, seq_length, input_size]. If false, the input tensor is expected to be [seq_length, batch_size, input_size].

  • Defaults to true
pub fn with_reverse(self, reverse: bool) -> RnnConfig

Sets the value for the field reverse.

If true, process the sequence in reverse order. This is useful for implementing reverse-direction RNNs (e.g., ONNX reverse direction).

  • Defaults to false
pub fn with_hidden_activation( self, hidden_activation: ActivationConfig, ) -> RnnConfig

Sets the value for the field hidden_activation.

Activation function applied to the hidden state before computing hidden output. Default is Tanh, which is standard for Rnn.

  • Defaults to "ActivationConfig::Tanh"
pub fn with_clip(self, clip: Option<f64>) -> RnnConfig

Sets the value for the field clip.

Optional hidden state clip threshold. If provided, hidden state values are clipped to the range [-clip, +clip] after each timestep. This can help prevent exploding values during inference.

  • Defaults to None
Source

impl RnnConfig

pub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> Rnn<B>
where B: Backend,

Initialize a new Rnn module.