Struct MomentumConfig
pub struct MomentumConfig {
pub momentum: f64,
pub dampening: f64,
pub nesterov: bool,
}Expand description
Configuration to create momentum.
Fields
momentum: f64Momentum factor
dampening: f64Dampening factor.
nesterov: boolEnables Nesterov momentum, see On the importance of initialization and momentum in deep learning.
Implementations
impl MomentumConfig
impl MomentumConfig
pub fn new() -> MomentumConfig
pub fn new() -> MomentumConfig
impl MomentumConfig
impl MomentumConfig
pub fn with_momentum(self, momentum: f64) -> MomentumConfig
pub fn with_momentum(self, momentum: f64) -> MomentumConfig
pub fn with_dampening(self, dampening: f64) -> MomentumConfig
pub fn with_dampening(self, dampening: f64) -> MomentumConfig
pub fn with_nesterov(self, nesterov: bool) -> MomentumConfig
pub fn with_nesterov(self, nesterov: bool) -> MomentumConfig
Sets the value for the field nesterov.
Enables Nesterov momentum, see On the importance of initialization and momentum in deep learning.
- Defaults to
false