Struct AsyncPolicy
pub struct AsyncPolicy<P>where
P: Policy,{ /* private fields */ }Expand description
An asynchronous policy using an inference server with autobatching.
Implementations
impl<P> AsyncPolicy<P>
impl<P> AsyncPolicy<P>
pub fn new(autobatch_size: usize, inner_policy: P) -> AsyncPolicy<P>
pub fn new(autobatch_size: usize, inner_policy: P) -> AsyncPolicy<P>
Create the policy.
Arguments
autobatch_size- Number of observations to accumulate before running a pass of inference.inner_policy- The policy used to take actions.
pub fn increment_agents(&self, num: usize)
pub fn increment_agents(&self, num: usize)
Increment the number of agents using the inference server.
pub fn decrement_agents(&self, num: usize)
pub fn decrement_agents(&self, num: usize)
Decrement the number of agents using the inference server.