SignalOps

Trait SignalOps 

pub trait SignalOps: Backend {
    // Required methods
    fn rfft(
        signal: Self::FloatTensorPrimitive,
        dim: usize,
        n: Option<usize>,
    ) -> (Self::FloatTensorPrimitive, Self::FloatTensorPrimitive);
    fn irfft(
        real: Self::FloatTensorPrimitive,
        imag: Self::FloatTensorPrimitive,
        dim: usize,
        n: Option<usize>,
    ) -> Self::FloatTensorPrimitive;
}
Signal processing operations supplied by a backend extension.

Required Methods

fn rfft( signal: Self::FloatTensorPrimitive, dim: usize, n: Option<usize>, ) -> (Self::FloatTensorPrimitive, Self::FloatTensorPrimitive)

Real FFT along dim, truncating or padding to n when supplied. Returns the real and imaginary components of the one-sided spectrum.

fn irfft( real: Self::FloatTensorPrimitive, imag: Self::FloatTensorPrimitive, dim: usize, n: Option<usize>, ) -> Self::FloatTensorPrimitive

Inverse real FFT along dim, with optional output length n.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors



impl SignalOps for Dispatch



impl SignalOps for Flex



impl<B, C> SignalOps for Autodiff<B, C>



impl<B> SignalOps for Fusion<B>