DTypeUsage

Enum DTypeUsage 

pub enum DTypeUsage {
    Storage,
    Arithmetic,
    Accelerated,
}
Describes how a data type can be used on a given device.

A data type may be supported for different classes of operations. Not all data types that appear in hardware or kernel implementations are suitable for general-purpose tensor operations.

Variants



Storage

The type can be stored in device memory and converted to and from other supported data types.



Arithmetic

The type supports general-purpose arithmetic and common tensor operations (e.g. elementwise ops, reductions, etc.).



Accelerated

The type is supported by hardware-accelerated execution paths.

This typically indicates support for accelerator-backed compute units (e.g., tensor cores executing MMA instructions) for high-performance operations such as matrix multiplication and operations that lower to it.

Notes

  • A type can be both Arithmetic and Accelerated if it supports general-purpose operations and accelerated paths.
  • If a type is marked as Accelerated but not Arithmetic, it is not suitable for general-purpose tensor operations and may only be used in specific accelerated operations.

Accelerated is a flag, not a detailed descriptor. It does not enumerate which operations are accelerated or which accelerator features are available.

Implementations



impl DTypeUsage

pub fn general() -> EnumSet<DTypeUsage>

Returns the usage set required for general-purpose tensor support.