Enum DeviceError
pub enum DeviceError {
UnsupportedDType {
device: String,
dtype: DType,
},
AlreadyInitialized {
device: String,
},
}Expand description
Errors that can occur during device-related operations.
This covers errors related to hardware capability mismatches, such as requesting a data type not supported by the device, and configuration errors like attempting to change a settings in an invalid context.
Variants
UnsupportedDType
Unsupported data type by the device.
Fields
AlreadyInitialized
Device settings have already been initialized.
Implementations
impl DeviceError
impl DeviceError
pub fn unsupported_dtype<D>(device: &D, dtype: DType) -> DeviceErrorwhere
D: DeviceOps,
pub fn unsupported_dtype<D>(device: &D, dtype: DType) -> DeviceErrorwhere
D: DeviceOps,
Helper to create a DeviceError::UnsupportedDType from any device.
pub fn already_initialized<D>(device: &D) -> DeviceErrorwhere
D: DeviceOps,
pub fn already_initialized<D>(device: &D) -> DeviceErrorwhere
D: DeviceOps,
Helper to create a DeviceError::AlreadyInitialized from any device.