Enum DeviceError
pub enum DeviceError {
UnsupportedDType {
device: String,
dtype: DType,
},
AlreadyInitialized {
device: String,
},
}Expand description
Errors returned by device-related operations.
Examples include attempting to use an unsupported data type on a device or initialization errors like attempting to change a settings in an invalid context.
Variants
UnsupportedDType
Unsupported data type by the device.
Fields
AlreadyInitialized
Device settings have already been initialized.
Implementations
impl DeviceError
impl DeviceError
pub fn unsupported_dtype<D>(device: &D, dtype: DType) -> DeviceError
pub fn unsupported_dtype<D>(device: &D, dtype: DType) -> DeviceError
Helper to create a DeviceError::UnsupportedDType from any device.
pub fn already_initialized<D>(device: &D) -> DeviceError
pub fn already_initialized<D>(device: &D) -> DeviceError
Helper to create a DeviceError::AlreadyInitialized from any device.