Enum PrimitiveConversionError
pub enum PrimitiveConversionError {
BackendMismatch(String),
KindMismatch(String),
}Expand description
Error returned when a DispatchTensor cannot be converted to the requested concrete primitive type.
Variants
BackendMismatch(String)
The dispatch tensor’s backend variant does not match the requested backend.
For example, extracting a Flex primitive from a CubeCL dispatch tensor. CubeCL runtime
aliases such as Wgpu and Cuda are not distinct backend types.
KindMismatch(String)
The tensor kind does not match the requested primitive kind.
For example, extracting a float primitive from an int tensor.