Enum TensorReadError
pub enum TensorReadError {
Execution(ExecutionError),
Data(DataError),
InvalidShape {
expected: usize,
actual: usize,
},
}Expand description
Errors that can occur while reading host data from a tensor.
Variants
Execution(ExecutionError)
Tensor execution failed while reading the data from the device.
Data(DataError)
The resulting TensorData could not satisfy the requested data operation.
InvalidShape
The tensor shape does not satisfy the read operation’s element-count requirement.