Struct AvgPoolOptions
pub struct AvgPoolOptions<const N: usize> {
pub kernel_size: [usize; N],
pub stride: [usize; N],
pub padding: [(usize, usize); N],
pub count_include_pad: bool,
pub ceil_mode: bool,
}Expand description
Average pooling options.
Fields
kernel_size: [usize; N]Kernel size (non-zero).
stride: [usize; N]Stride (non-zero).
padding: [(usize, usize); N]Padding as (begin, end) pairs for each spatial dimension.
count_include_pad: boolIf true, padded values are counted in the denominator of the average.
ceil_mode: boolIf true, use ceiling instead of floor for output size calculation.
Implementations
impl<const N: usize> AvgPoolOptions<N>
impl<const N: usize> AvgPoolOptions<N>
pub fn new(kernel_size: [usize; N]) -> AvgPoolOptions<N>
pub fn new(kernel_size: [usize; N]) -> AvgPoolOptions<N>
Constructs average pooling options with the given kernel size.
Defaults to a stride equal to the kernel size, no padding, counting padded values in the average and floor mode.
pub fn with_stride(self, stride: [usize; N]) -> AvgPoolOptions<N>
pub fn with_stride(self, stride: [usize; N]) -> AvgPoolOptions<N>
Sets the stride.
pub fn with_padding(self, padding: [usize; N]) -> AvgPoolOptions<N>
pub fn with_padding(self, padding: [usize; N]) -> AvgPoolOptions<N>
Sets symmetric padding for every spatial dimension.
pub fn with_padding_pairs(
self,
padding: [(usize, usize); N],
) -> AvgPoolOptions<N>
pub fn with_padding_pairs( self, padding: [(usize, usize); N], ) -> AvgPoolOptions<N>
Sets explicit (begin, end) padding for every spatial dimension.
pub fn with_count_include_pad(
self,
count_include_pad: bool,
) -> AvgPoolOptions<N>
pub fn with_count_include_pad( self, count_include_pad: bool, ) -> AvgPoolOptions<N>
Sets whether padded values are counted in the denominator of the average.
pub fn with_ceil_mode(self, ceil_mode: bool) -> AvgPoolOptions<N>
pub fn with_ceil_mode(self, ceil_mode: bool) -> AvgPoolOptions<N>
Sets whether to use ceiling instead of floor for output size calculation.
pub fn is_asymmetric(&self) -> bool
pub fn is_asymmetric(&self) -> bool
Returns true if padding is asymmetric.