Enum QuantStore
pub enum QuantStore {
Native,
PackedNative(usize),
PackedU32(usize),
}Expand description
Data type used to stored quantized values.
Variants
Native
Native quantization doesn’t require packing and unpacking.
PackedNative(usize)
Store packed quantized values in a natively supported packing format (i.e. e2m1x2). Argument is the dimension the tensor is packed on, starting from the innermost dimension.
PackedU32(usize)
Store packed quantized values in a 4-byte unsigned integer. Argument is the dimension the tensor is packed on, starting from the innermost dimension.
Implementations
impl QuantStore
impl QuantStore
pub fn size_bits(&self, value: &QuantValue) -> usize
pub fn size_bits(&self, value: &QuantValue) -> usize
Returns the size of the quantization input type in bits.