dispatch_int_dtype

Macro dispatch_int_dtype 

macro_rules! dispatch_int_dtype {
    ($dtype:expr, |$ty:ident| $body:expr) => { ... };
}
Dispatches connected components based on the int dtype, binding a concrete integer type to enable generic instantiations without extra trait bounds (after removing ElementComparison from Element).