Enum BackendTensor
pub enum BackendTensor<B>where
B: BackendTypes,{
Float(<B as BackendTypes>::FloatTensorPrimitive),
Int(<B as BackendTypes>::IntTensorPrimitive),
Bool(<B as BackendTypes>::BoolTensorPrimitive),
Quantized(<B as BackendTypes>::QuantizedTensorPrimitive),
Autodiff(<Autodiff<B> as BackendTypes>::FloatTensorPrimitive),
}Expand description
Tensor which points to a backend tensor primitive kind.
Variants
Float(<B as BackendTypes>::FloatTensorPrimitive)
Float tensor handle.
Int(<B as BackendTypes>::IntTensorPrimitive)
Int tensor handle.
Bool(<B as BackendTypes>::BoolTensorPrimitive)
Bool tensor handle.
Quantized(<B as BackendTypes>::QuantizedTensorPrimitive)
Quantized tensor handle.
Autodiff(<Autodiff<B> as BackendTypes>::FloatTensorPrimitive)
Autodiff float tensor handle.
Implementations
impl<B> BackendTensor<B>where
B: Backend,
impl<B> BackendTensor<B>where
B: Backend,
pub fn float(self) -> <B as BackendTypes>::FloatTensorPrimitive
pub fn float(self) -> <B as BackendTypes>::FloatTensorPrimitive
Returns the inner float tensor primitive.
pub fn as_float(&self) -> &<B as BackendTypes>::FloatTensorPrimitive
pub fn as_float(&self) -> &<B as BackendTypes>::FloatTensorPrimitive
Returns the inner float tensor primitive.
pub fn int(self) -> <B as BackendTypes>::IntTensorPrimitive
pub fn int(self) -> <B as BackendTypes>::IntTensorPrimitive
Returns the inner int tensor primitive.
pub fn bool(self) -> <B as BackendTypes>::BoolTensorPrimitive
pub fn bool(self) -> <B as BackendTypes>::BoolTensorPrimitive
Returns the inner bool tensor primitive.
pub fn quantized(self) -> <B as BackendTypes>::QuantizedTensorPrimitive
pub fn quantized(self) -> <B as BackendTypes>::QuantizedTensorPrimitive
Returns the inner quantized tensor primitive.
pub fn autodiff(self) -> <Autodiff<B> as BackendTypes>::FloatTensorPrimitive
pub fn autodiff(self) -> <Autodiff<B> as BackendTypes>::FloatTensorPrimitive
Returns the inner autodiff tensor primitive.
pub fn as_autodiff(
&self,
) -> &<Autodiff<B> as BackendTypes>::FloatTensorPrimitive
pub fn as_autodiff( &self, ) -> &<Autodiff<B> as BackendTypes>::FloatTensorPrimitive
Returns the inner autodiff tensor primitive.
pub fn autodiff_inner(self) -> <B as BackendTypes>::FloatTensorPrimitive
pub fn autodiff_inner(self) -> <B as BackendTypes>::FloatTensorPrimitive
Returns the inner autodiff tensor primitive.
pub fn into_autodiff(self) -> BackendTensor<Autodiff<B>>
pub fn into_autodiff(self) -> BackendTensor<Autodiff<B>>
Lift a handle for backend B into the equivalent handle for Autodiff<B>.
An already-tracked float (Autodiff) becomes the Float handle of Autodiff<B>; int/bool/
quantized handles are re-tagged unchanged (those primitives are shared between B and
Autodiff<B>). An untracked Float handle is invalid here (under autodiff, float tensors
arrive tracked), so it panics.