Enum BaseOperationIr
pub enum BaseOperationIr {
Show 30 variants
Reshape(ShapeOpIr),
SwapDims(SwapDimsOpIr),
Permute(PermuteOpIr),
Flip(FlipOpIr),
Expand(ShapeOpIr),
Unfold(UnfoldOpIr),
Slice(SliceOpIr),
SliceAssign(SliceAssignOpIr),
Select(SelectOpIr),
SelectAssign(SelectAssignOpIr),
MaskWhere(MaskWhereOpIr),
MaskFill(MaskFillOpIr),
Gather(GatherOpIr),
Scatter(ScatterOpIr),
ScatterNd(ScatterNdOpIr),
GatherNd(GatherNdOpIr),
Equal(BinaryOpIr),
EqualElem(ScalarOpIr),
RepeatDim(RepeatDimOpIr),
Cat(CatOpIr),
Cast(CastOpIr),
Empty(CreationOpIr),
Ones(CreationOpIr),
Zeros(CreationOpIr),
NotEqual(BinaryOpIr),
NotEqualElem(ScalarOpIr),
All(ReduceOpIr),
Any(ReduceOpIr),
AllDim(ReduceDimOpIr),
AnyDim(ReduceDimOpIr),
}Expand description
Basic operations that can be done on any tensor type.
Variants
Reshape(ShapeOpIr)
SwapDims(SwapDimsOpIr)
Permute(PermuteOpIr)
Flip(FlipOpIr)
Expand(ShapeOpIr)
Unfold(UnfoldOpIr)
Unfold windows along an axis.
Slice(SliceOpIr)
SliceAssign(SliceAssignOpIr)
Operation corresponding to:
Float => slice assign. Int => slice assign. Bool => slice assign.
Select(SelectOpIr)
SelectAssign(SelectAssignOpIr)
Operation corresponding to:
Float => select assign. Int => select assign. Bool => select assign.
MaskWhere(MaskWhereOpIr)
Operation corresponding to:
Float => mask where. Int => mask where. Bool => mask where.
MaskFill(MaskFillOpIr)
Gather(GatherOpIr)
Scatter(ScatterOpIr)
ScatterNd(ScatterNdOpIr)
Multi-dimensional scatter operation.
GatherNd(GatherNdOpIr)
Multi-dimensional gather operation.
Equal(BinaryOpIr)
EqualElem(ScalarOpIr)
Operation corresponding to:
Float => equal elem. Int => equal elem. Bool => equal elem.
RepeatDim(RepeatDimOpIr)
Operation corresponding to:
Float => repeat dim. Int => repeat dim. Bool => repeat dim.
Cat(CatOpIr)
Cast(CastOpIr)
Cast operation, no direct operation and should be supported by fusion backend.
Empty(CreationOpIr)
Ones(CreationOpIr)
Zeros(CreationOpIr)
NotEqual(BinaryOpIr)
NotEqualElem(ScalarOpIr)
Operation corresponding to:
Float => not_equal_elem. Int => not_equal_elem. Bool => not_equal_elem.
All(ReduceOpIr)
Reduce-all over the input tensor.
Float/Int input is treated as a non-zero check; bool input is the value itself. Output is a single-element bool tensor.
Any(ReduceOpIr)
Reduce-any over the input tensor.
AllDim(ReduceDimOpIr)
Reduce-all along a dim.
AnyDim(ReduceDimOpIr)
Reduce-any along a dim.