Enum NumericOperationIr
pub enum NumericOperationIr {
Show 56 variants
Add(BinaryOpIr),
AddScalar(ScalarOpIr),
Sub(BinaryOpIr),
SubScalar(ScalarOpIr),
Div(BinaryOpIr),
DivScalar(ScalarOpIr),
Rem(BinaryOpIr),
RemScalar(ScalarOpIr),
Mul(BinaryOpIr),
MulScalar(ScalarOpIr),
Abs(UnaryOpIr),
Full(FullOpIr),
MeanDim(ReduceDimOpIr),
Mean(ReduceOpIr),
Sum(ReduceOpIr),
SumDim(ReduceDimOpIr),
SumDims(ReduceDimsOpIr),
Prod(ReduceOpIr),
ProdDim(ReduceDimOpIr),
Greater(BinaryOpIr),
GreaterElem(ScalarOpIr),
GreaterEqual(BinaryOpIr),
GreaterEqualElem(ScalarOpIr),
Lower(BinaryOpIr),
LowerElem(ScalarOpIr),
LowerEqual(BinaryOpIr),
LowerEqualElem(ScalarOpIr),
ArgMax(ReduceDimOpIr),
ArgTopK(ReduceDimOpIr),
TopK(ReduceDimOpIr),
TopKWithIndices(TopKWithIndicesOpIr),
ArgMin(ReduceDimOpIr),
Max(ReduceOpIr),
MaxDimWithIndices(ReduceDimWithIndicesOpIr),
MinDimWithIndices(ReduceDimWithIndicesOpIr),
Min(ReduceOpIr),
MaxDim(ReduceDimOpIr),
MinDim(ReduceDimOpIr),
MaxAbs(ReduceOpIr),
MaxAbsDim(ReduceDimOpIr),
Clamp(ClampOpIr),
IntRandom(RandomOpIr),
Powi(BinaryOpIr),
PowiScalar(ScalarOpIr),
CumSum(DimOpIr),
CumProd(DimOpIr),
CumMin(DimOpIr),
CumMax(DimOpIr),
Neg(UnaryOpIr),
Sign(UnaryOpIr),
ClampMin(ScalarOpIr),
ClampMax(ScalarOpIr),
Sort(SortOpIr),
SortWithIndices(SortWithIndicesOpIr),
ArgSort(SortOpIr),
Pad(PadOpIr),
}Expand description
Numeric operations on int and float tensors.
Variants
Add(BinaryOpIr)
AddScalar(ScalarOpIr)
Operation corresponding to:
Float => add scalar. Int => add scalar.
Sub(BinaryOpIr)
SubScalar(ScalarOpIr)
Operation corresponding to:
Float => sub scalar. Int => sub scalar.
Div(BinaryOpIr)
DivScalar(ScalarOpIr)
Operation corresponding to:
Float => div scalar. Int => div scalar.
Rem(BinaryOpIr)
RemScalar(ScalarOpIr)
Operation corresponding to:
Float => rem scalar. Int => rem scalar.
Mul(BinaryOpIr)
MulScalar(ScalarOpIr)
Operation corresponding to:
Float => mul scalar. Int => mul scalar.
Abs(UnaryOpIr)
Full(FullOpIr)
MeanDim(ReduceDimOpIr)
Mean(ReduceOpIr)
Sum(ReduceOpIr)
SumDim(ReduceDimOpIr)
SumDims(ReduceDimsOpIr)
Operation corresponding to summing several dimensions at once.
Prod(ReduceOpIr)
ProdDim(ReduceDimOpIr)
Greater(BinaryOpIr)
GreaterElem(ScalarOpIr)
Operation corresponding to:
Float => greater elem. Int => greater elem.
GreaterEqual(BinaryOpIr)
Operation corresponding to:
Float => greater equal. Int => greater elem.
GreaterEqualElem(ScalarOpIr)
Operation corresponding to:
Float => greater equal elem. Int => greater equal elem.
Lower(BinaryOpIr)
LowerElem(ScalarOpIr)
Operation corresponding to:
Float => lower elem. Int => lower elem.
LowerEqual(BinaryOpIr)
Operation corresponding to:
Float => lower equal. Int => lower equal.
LowerEqualElem(ScalarOpIr)
Operation corresponding to:
Float => lower equal elem. Int => lower equal elem.
ArgMax(ReduceDimOpIr)
ArgTopK(ReduceDimOpIr)
TopK(ReduceDimOpIr)
TopKWithIndices(TopKWithIndicesOpIr)
Operation corresponding to:
Float => topk with indices. Int => topk with indices.
ArgMin(ReduceDimOpIr)
Max(ReduceOpIr)
MaxDimWithIndices(ReduceDimWithIndicesOpIr)
Operation corresponding to:
Float => max dim with indices. Int => max dim with indices.
MinDimWithIndices(ReduceDimWithIndicesOpIr)
Operation corresponding to:
Float => min dim with indices. Int => min dim with indices.
Min(ReduceOpIr)
MaxDim(ReduceDimOpIr)
MinDim(ReduceDimOpIr)
MaxAbs(ReduceOpIr)
MaxAbsDim(ReduceDimOpIr)
Operation corresponding to:
Float => max_abs dim. Int => max_abs dim.
Clamp(ClampOpIr)
IntRandom(RandomOpIr)
Operation corresponding to:
Int => random.
Powi(BinaryOpIr)
PowiScalar(ScalarOpIr)
Operation corresponding to:
Float => powi_scalar. Int => powi_scalar.
CumSum(DimOpIr)
CumProd(DimOpIr)
CumMin(DimOpIr)
CumMax(DimOpIr)
Neg(UnaryOpIr)
Sign(UnaryOpIr)
ClampMin(ScalarOpIr)
ClampMax(ScalarOpIr)
Sort(SortOpIr)
Sort along a dim. Output shares the input’s shape and dtype.
SortWithIndices(SortWithIndicesOpIr)
Sort along a dim, also returning the source indices.
ArgSort(SortOpIr)
Sort along a dim and return only the indices (i.e., the argsort).
Pad(PadOpIr)