Function global_scale_dtype
pub fn global_scale_dtype(scheme: &QuantScheme) -> Option<ScaleDtype>Expand description
The dtype of the per-tensor scale block scales are normalized against, for a two-level scheme.
QuantScheme::tensor_scale answers for a per-tensor scheme too, where the scale is the whole
reconstruction rather than a factor over block scales.