Struct SequentialLrSchedulerConfig
pub struct SequentialLrSchedulerConfig { /* private fields */ }Expand description
Configuration for a sequential learning rate scheduler.
Each milestone is the number of completed calls to LrScheduler::step at which the next
scheduler takes over. Therefore, N schedulers require exactly N - 1 milestones. Milestones
must be greater than zero and strictly increasing.
Example
The linear scheduler below handles the first 100 steps, after which the cosine scheduler starts from its own first step.
use burn_optim::lr_scheduler::{
LrSchedulerConfig,
cosine::CosineAnnealingLrSchedulerConfig, linear::LinearLrSchedulerConfig,
sequential::SequentialLrSchedulerConfig,
};
let config = SequentialLrSchedulerConfig::new(
vec![
LrSchedulerConfig::Linear(LinearLrSchedulerConfig::new(1e-5, 1e-2, 100)),
LrSchedulerConfig::Cosine(CosineAnnealingLrSchedulerConfig::new(1e-2, 900)),
],
vec![100],
);
let scheduler = config.init().unwrap();Implementations
impl SequentialLrSchedulerConfig
impl SequentialLrSchedulerConfig
pub fn new(
schedulers: Vec<LrSchedulerConfig>,
milestones: Vec<usize>,
) -> SequentialLrSchedulerConfig
pub fn new( schedulers: Vec<LrSchedulerConfig>, milestones: Vec<usize>, ) -> SequentialLrSchedulerConfig
impl SequentialLrSchedulerConfig
impl SequentialLrSchedulerConfig
pub fn init(&self) -> Result<ModuleLrScheduler, String>
pub fn init(&self) -> Result<ModuleLrScheduler, String>
Initializes a module learning rate scheduler.
Errors
An error is returned when there are no schedulers, the number of milestones is not one less than the number of schedulers, milestones are zero or not strictly increasing, or a child scheduler configuration is invalid.