Struct SmoothL1LossConfig
pub struct SmoothL1LossConfig {
pub beta: f32,
}Expand description
Configuration for the SmoothL1Loss module.
Smooth L1 loss combines L1 and L2 loss, using L2 loss for small errors (below beta) and L1 loss for large errors (above beta). This makes it less sensitive to outliers than MSE while maintaining smooth gradients near zero.
Example
ⓘ
use burn_nn::loss::{SmoothL1LossConfig, Reduction};
// Create Smooth L1 loss with default beta=1.0
let smooth_l1 = SmoothL1LossConfig::new().init();
// Create with custom beta
let smooth_l1_custom = SmoothL1LossConfig::new().with_beta(0.5).init();Fields
beta: f32Specifies the threshold at which to change between L1 and L2 loss. The value must be positive. Default: 1.0
Implementations
impl SmoothL1LossConfig
impl SmoothL1LossConfig
pub fn new() -> SmoothL1LossConfig
pub fn new() -> SmoothL1LossConfig
impl SmoothL1LossConfig
impl SmoothL1LossConfig
pub fn with_beta(self, beta: f32) -> SmoothL1LossConfig
pub fn with_beta(self, beta: f32) -> SmoothL1LossConfig
Sets the value for the field beta.
Specifies the threshold at which to change between L1 and L2 loss. The value must be positive. Default: 1.0
- Defaults to
1.0
impl SmoothL1LossConfig
impl SmoothL1LossConfig
pub fn init(&self) -> SmoothL1Loss
pub fn init(&self) -> SmoothL1Loss