Conv3dConfig

Struct Conv3dConfig 

pub struct Conv3dConfig {
    pub channels: [usize; 2],
    pub kernel_size: [usize; 3],
    pub stride: [usize; 3],
    pub dilation: [usize; 3],
    pub groups: usize,
    pub padding: PaddingConfig3d,
    pub bias: bool,
    pub initializer: Initializer,
}
Configuration to create a 3D convolution layer, using the init function.

Fields

channels: [usize; 2]

The number of channels.

kernel_size: [usize; 3]

The size of the kernel.

stride: [usize; 3]

The stride of the convolution.

dilation: [usize; 3]

Spacing between kernel elements.

groups: usize

Controls the connections between input and output channels.

padding: PaddingConfig3d

The padding configuration.

bias: bool

If bias should be added to the output.

initializer: Initializer

The type of function used to initialize neural network parameters

Implementations

Source

impl Conv3dConfig

pub fn new(channels: [usize; 2], kernel_size: [usize; 3]) -> Conv3dConfig

Create a new instance of the config.

Arguments
Required Arguments
channels

The number of channels.

kernel_size

The size of the kernel.

Default Arguments
stride

The stride of the convolution.

  • Defaults to "[1, 1, 1]"
dilation

Spacing between kernel elements.

  • Defaults to "[1, 1, 1]"
groups

Controls the connections between input and output channels.

  • Defaults to "1"
padding

The padding configuration.

  • Defaults to "PaddingConfig3d::Valid"
bias

If bias should be added to the output.

  • Defaults to true
initializer

The type of function used to initialize neural network parameters

  • Defaults to "Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0),fan_out_only:false}"
Source

impl Conv3dConfig

pub fn with_stride(self, stride: [usize; 3]) -> Conv3dConfig

Sets the value for the field stride.

The stride of the convolution.

  • Defaults to "[1, 1, 1]"
pub fn with_dilation(self, dilation: [usize; 3]) -> Conv3dConfig

Sets the value for the field dilation.

Spacing between kernel elements.

  • Defaults to "[1, 1, 1]"
pub fn with_groups(self, groups: usize) -> Conv3dConfig

Sets the value for the field groups.

Controls the connections between input and output channels.

  • Defaults to "1"
pub fn with_padding(self, padding: PaddingConfig3d) -> Conv3dConfig

Sets the value for the field padding.

The padding configuration.

  • Defaults to "PaddingConfig3d::Valid"
pub fn with_bias(self, bias: bool) -> Conv3dConfig

Sets the value for the field bias.

If bias should be added to the output.

  • Defaults to true
pub fn with_initializer(self, initializer: Initializer) -> Conv3dConfig

Sets the value for the field initializer.

The type of function used to initialize neural network parameters

  • Defaults to "Initializer::KaimingUniform{gain:1.0/num_traits::Float::sqrt(3.0),fan_out_only:false}"
Source

impl Conv3dConfig

pub fn init<B>(&self, device: &<B as BackendTypes>::Device) -> Conv3d<B>
where B: Backend,

Initialize a new conv3d module.