pub struct LocalResponseNorm { /* private fields */ }Expand description
Applies Local Response Normalization as described in ImageNet Classification with Deep Convolutional Neural Networks.
Y = X / (k + (alpha / size) * sum(X^2))^beta
Where the sum is computed over a sliding window of size channels.
For odd size, the window is centered on each channel position.
For even size, the window uses asymmetric padding and includes the current
channel plus one extra channel on the positive side.
Should be created using LocalResponseNormConfig.
Implementations