pub struct AvgPool1dConfig {
pub kernel_size: usize,
pub stride: usize,
pub padding: PaddingConfig1d,
pub count_include_pad: bool,
pub ceil_mode: bool,
}Expand description
Configuration to create a 1D avg pooling layer using the init function.
Fields
kernel_size: usizeThe size of the kernel.
stride: usizeThe stride.
padding: PaddingConfig1dThe padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
count_include_pad: boolIf the padding is counted in the denominator when computing the average.
ceil_mode: boolIf true, use ceiling instead of floor for output size calculation.
Implementations
Sourceimpl AvgPool1dConfig
impl AvgPool1dConfig
Sourcepub fn new(kernel_size: usize) -> AvgPool1dConfig
pub fn new(kernel_size: usize) -> AvgPool1dConfig
Create a new instance of the config.
Arguments
Required Arguments
kernel_size
The size of the kernel.
Default Arguments
stride
The stride.
- Defaults to
"kernel_size"
padding
The padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
- Defaults to
"PaddingConfig1d::Valid"
count_include_pad
If the padding is counted in the denominator when computing the average.
- Defaults to
"true"
ceil_mode
If true, use ceiling instead of floor for output size calculation.
- Defaults to
"false"
Sourceimpl AvgPool1dConfig
impl AvgPool1dConfig
Sourcepub fn with_stride(self, stride: usize) -> AvgPool1dConfig
pub fn with_stride(self, stride: usize) -> AvgPool1dConfig
Sourcepub fn with_padding(self, padding: PaddingConfig1d) -> AvgPool1dConfig
pub fn with_padding(self, padding: PaddingConfig1d) -> AvgPool1dConfig
Sets the value for the field padding.
The padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
- Defaults to
"PaddingConfig1d::Valid"
Sourcepub fn with_count_include_pad(self, count_include_pad: bool) -> AvgPool1dConfig
pub fn with_count_include_pad(self, count_include_pad: bool) -> AvgPool1dConfig
Sets the value for the field count_include_pad.
If the padding is counted in the denominator when computing the average.
- Defaults to
"true"
Sourcepub fn with_ceil_mode(self, ceil_mode: bool) -> AvgPool1dConfig
pub fn with_ceil_mode(self, ceil_mode: bool) -> AvgPool1dConfig
Sets the value for the field ceil_mode.
If true, use ceiling instead of floor for output size calculation.
- Defaults to
"false"
Sourceimpl AvgPool1dConfig
impl AvgPool1dConfig
Sourcepub fn init(&self) -> AvgPool1d
pub fn init(&self) -> AvgPool1d
Initialize a new avg pool 1d module.