Struct MaxPool1dConfig
pub struct MaxPool1dConfig {
pub kernel_size: usize,
pub stride: usize,
pub padding: PaddingConfig1d,
pub dilation: usize,
pub ceil_mode: bool,
}Expand description
Configuration to create a 1D max pooling layer using the init function.
Fields
kernel_size: usizeThe size of the kernel.
stride: usizeThe stride.
padding: PaddingConfig1dThe padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
dilation: usizeThe dilation.
ceil_mode: boolIf true, use ceiling instead of floor for output size calculation.
Implementations
impl MaxPool1dConfig
impl MaxPool1dConfig
pub fn new(kernel_size: usize) -> MaxPool1dConfig
pub fn new(kernel_size: usize) -> MaxPool1dConfig
Create a new instance of the config.
Arguments
Required Arguments
kernel_size
The size of the kernel.
Default Arguments
stride
The stride.
- Defaults to
"kernel_size"
padding
The padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
- Defaults to
"PaddingConfig1d::Valid"
dilation
The dilation.
- Defaults to
"1"
ceil_mode
If true, use ceiling instead of floor for output size calculation.
- Defaults to
"false"
impl MaxPool1dConfig
impl MaxPool1dConfig
pub fn with_stride(self, stride: usize) -> MaxPool1dConfig
pub fn with_stride(self, stride: usize) -> MaxPool1dConfig
pub fn with_padding(self, padding: PaddingConfig1d) -> MaxPool1dConfig
pub fn with_padding(self, padding: PaddingConfig1d) -> MaxPool1dConfig
Sets the value for the field padding.
The padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
- Defaults to
"PaddingConfig1d::Valid"
pub fn with_dilation(self, dilation: usize) -> MaxPool1dConfig
pub fn with_dilation(self, dilation: usize) -> MaxPool1dConfig
pub fn with_ceil_mode(self, ceil_mode: bool) -> MaxPool1dConfig
pub fn with_ceil_mode(self, ceil_mode: bool) -> MaxPool1dConfig
Sets the value for the field ceil_mode.
If true, use ceiling instead of floor for output size calculation.
- Defaults to
"false"
impl MaxPool1dConfig
impl MaxPool1dConfig
pub fn init(&self) -> MaxPool1d
pub fn init(&self) -> MaxPool1d
Initialize a new max pool 1d module.