Struct MaxPool2dConfig
pub struct MaxPool2dConfig {
pub kernel_size: [usize; 2],
pub strides: [usize; 2],
pub padding: PaddingConfig2d,
pub dilation: [usize; 2],
pub ceil_mode: bool,
}Expand description
Configuration to create a 2D max pooling layer using the init function.
Fields
kernel_size: [usize; 2]The size of the kernel.
strides: [usize; 2]The strides.
padding: PaddingConfig2dThe padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
dilation: [usize; 2]The dilation.
ceil_mode: boolIf true, use ceiling instead of floor for output size calculation.
Implementations
impl MaxPool2dConfig
impl MaxPool2dConfig
pub fn new(kernel_size: [usize; 2]) -> MaxPool2dConfig
pub fn new(kernel_size: [usize; 2]) -> MaxPool2dConfig
Create a new instance of the config.
Arguments
Required Arguments
kernel_size
The size of the kernel.
Default Arguments
strides
The strides.
- Defaults to
"kernel_size"
padding
The padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
- Defaults to
"PaddingConfig2d::Valid"
dilation
The dilation.
- Defaults to
"[1, 1]"
ceil_mode
If true, use ceiling instead of floor for output size calculation.
- Defaults to
"false"
impl MaxPool2dConfig
impl MaxPool2dConfig
pub fn with_strides(self, strides: [usize; 2]) -> MaxPool2dConfig
pub fn with_strides(self, strides: [usize; 2]) -> MaxPool2dConfig
pub fn with_padding(self, padding: PaddingConfig2d) -> MaxPool2dConfig
pub fn with_padding(self, padding: PaddingConfig2d) -> MaxPool2dConfig
Sets the value for the field padding.
The padding configuration.
Supports symmetric and asymmetric padding. Same padding with even kernel sizes
will automatically use asymmetric padding to preserve input dimensions.
- Defaults to
"PaddingConfig2d::Valid"
pub fn with_dilation(self, dilation: [usize; 2]) -> MaxPool2dConfig
pub fn with_dilation(self, dilation: [usize; 2]) -> MaxPool2dConfig
pub fn with_ceil_mode(self, ceil_mode: bool) -> MaxPool2dConfig
pub fn with_ceil_mode(self, ceil_mode: bool) -> MaxPool2dConfig
Sets the value for the field ceil_mode.
If true, use ceiling instead of floor for output size calculation.
- Defaults to
"false"
impl MaxPool2dConfig
impl MaxPool2dConfig
pub fn init(&self) -> MaxPool2d
pub fn init(&self) -> MaxPool2d
Initialize a new max pool 2d module.