Macro dispatch_bool_dtype
macro_rules! dispatch_bool_dtype {
($dtype:expr, |$ty:ident| $body:expr) => { ... };
}Expand description
Dispatches connected components based on the bool dtype, binding a concrete
integer type to enable generic instantiations without extra trait bounds (after removing
ElementComparison from Element).